@@ -42,24 +42,23 @@ char *PipeInput(char *m_szMessage);
 class CPX_FileTransfer
 {
 public:
-	CPX_FileTransfer(ConstFileList &lFileList, const char *szFileName);
+  CPX_FileTransfer(ConstFileList &lFileList, const char *szFileName);
+  virtual ~CPX_FileTransfer();
 
-	virtual ~CPX_FileTransfer()	{ }
-
-	bool IsValid()	{ return m_bValid; }
-	ConstFileList GetFileList()	{ return m_lFileList; }
-	const char *GetFilename()	{ return m_szFilename; }
-	const char *GetDescription() { return m_szDesc; }
-	unsigned long GetFileSize()	{ return m_nFileSize; }
+  bool IsValid()	{ return m_bValid; }
+  ConstFileList GetFileList()	{ return m_lFileList; }
+  const char *GetFilename()	{ return m_szFilename; }
+  const char *GetDescription() { return m_szDesc; }
+  unsigned long GetFileSize()	{ return m_nFileSize; }
 
 protected:
-	CPX_FileTransfer();
+  CPX_FileTransfer();
 
-	bool					m_bValid;
-	char					*m_szDesc;
-	char					*m_szFilename;
-	ConstFileList				m_lFileList;
-	unsigned long				m_nFileSize;
+  bool          m_bValid;
+  char          *m_szDesc;
+  char          *m_szFilename;
+  ConstFileList m_lFileList;
+  unsigned long m_nFileSize;
 };
 
 
@@ -69,19 +68,19 @@ protected:
 class CPacket
 {
 public:
-   virtual ~CPacket() { if (buffer != NULL) delete buffer; }
+   virtual ~CPacket();
 
    CBuffer *getBuffer()  { return buffer; };
    virtual CBuffer *Finalize(INetSocket *) { return NULL; }
 
-   virtual const unsigned short Sequence() = 0;
-   virtual const unsigned short SubSequence() = 0;
-   virtual const unsigned short Command() = 0;
-   virtual const unsigned short SubCommand() = 0;
+   virtual unsigned short Sequence() = 0;
+   virtual unsigned short SubSequence() = 0;
+   virtual unsigned short Command() = 0;
+   virtual unsigned short SubCommand() = 0;
 
-   virtual const unsigned char  Channel()   { return ICQ_CHNxNONE; }
-   virtual const unsigned long  SNAC()      { return 0; }
-   virtual const unsigned short ExtraInfo() { return 0; }
+   virtual unsigned char  Channel()   { return ICQ_CHNxNONE; }
+   virtual unsigned long  SNAC()      { return 0; }
+   virtual unsigned short ExtraInfo() { return 0; }
 
 
    static void SetMode(char c) { s_nMode = c; }
@@ -95,7 +94,7 @@ public:
    static unsigned long LocalIp() { return s_nLocalIp; }
 
 protected:
-   CPacket() { buffer = NULL; };
+   CPacket();
 
    CBuffer *buffer;
    unsigned short m_nSize;
@@ -113,18 +112,20 @@ protected:
 class CSrvPacketTcp : public CPacket
 {
 public:
+  virtual ~CSrvPacketTcp();
+
   // Packet details
-  virtual const unsigned char  Channel()     { return m_nChannel; }
-  virtual const unsigned short Sequence()    { return m_nSequence; }
-  virtual const unsigned short SubSequence() { return m_nSubSequence; }
-  virtual const unsigned long  SNAC() { return ((m_nFamily << 16) | (m_nSubType)); }
-  virtual const unsigned short SubCommand()  { return m_nSubCommand; }
+  virtual unsigned char  Channel()     { return m_nChannel; }
+  virtual unsigned short Sequence()    { return m_nSequence; }
+  virtual unsigned short SubSequence() { return m_nSubSequence; }
+  virtual unsigned long  SNAC() { return ((m_nFamily << 16) | (m_nSubType)); }
+  virtual unsigned short SubCommand()  { return m_nSubCommand; }
 
   // Not used anymore here, use SNAC instead.
-  virtual const unsigned short Command()     { return 0; }
+  virtual unsigned short Command()     { return 0; }
 
   // Misc.
-  virtual const unsigned short ExtraInfo() { return m_nExtraInfo; }
+  virtual unsigned short ExtraInfo() { return m_nExtraInfo; }
   virtual CBuffer *Finalize(INetSocket *);
   void SetExtraInfo(unsigned short e)  { m_nExtraInfo = e; }
 
@@ -154,11 +155,13 @@ protected:
 class CPacketUdp : public CPacket
 {
 public:
+   virtual ~CPacketUdp();
+
    virtual CBuffer *Finalize(INetSocket *);
-   virtual const unsigned short Sequence() { return m_nSequence; }
-   virtual const unsigned short SubSequence() { return m_nSubSequence; }
-   virtual const unsigned short Command()  { return m_nCommand; }
-   virtual const unsigned short SubCommand()  { return 0; }
+   virtual unsigned short Sequence() { return m_nSequence; }
+   virtual unsigned short SubSequence() { return m_nSubSequence; }
+   virtual unsigned short Command()  { return m_nCommand; }
+   virtual unsigned short SubCommand()  { return 0; }
 protected:
    CPacketUdp(unsigned short _nCommand);
    void InitBuffer();
@@ -198,6 +201,7 @@ class CPU_Logon : public CSrvPacketTcp
 {
 public:
   CPU_Logon(const char *_szPassword, const char *_szUin, unsigned short _nLogonStatus);
+  virtual ~CPU_Logon();
 protected:
   unsigned long  m_nLogonStatus;
   unsigned long  m_nTcpVersion;
@@ -208,6 +212,7 @@ class CPU_Logoff : public CSrvPacketTcp
 {
 public:
    CPU_Logoff();
+   virtual ~CPU_Logoff();
 };
 
 //-----SendCookie---------------------------------------------------------------
@@ -215,6 +220,7 @@ class CPU_SendCookie : public CSrvPacketTcp
 {
 public:
   CPU_SendCookie(const char *, int len);
+  virtual ~CPU_SendCookie();
 };
 
 //-----CommonFamily----------------------------------------------------------
@@ -222,6 +228,7 @@ class CPU_CommonFamily : public CSrvPacketTcp
 {
 public:
   CPU_CommonFamily(unsigned short Family, unsigned short SubType);
+  virtual ~CPU_CommonFamily();
 
 protected:
   void InitBuffer();
@@ -230,8 +237,8 @@ protected:
 class CPU_GenericFamily : public CPU_CommonFamily
 {
 public:
-    CPU_GenericFamily(unsigned short Family, unsigned short SubType);
-
+  CPU_GenericFamily(unsigned short Family, unsigned short SubType);
+  virtual ~CPU_GenericFamily();
 };
 
 #if ICQ_VERSION == 2 || ICQ_VERSION == 6
@@ -244,10 +251,10 @@ public:
   CPU_Register(const char *_szPasswd);
   virtual ~CPU_Register();
 
-  virtual const unsigned short Sequence() { return m_nSequence; }
-  virtual const unsigned short SubSequence() { return 0; }
-  virtual const unsigned short Command()  { return m_nCommand; }
-  virtual const unsigned short SubCommand() { return 0; }
+  virtual unsigned short Sequence() { return m_nSequence; }
+  virtual unsigned short SubSequence() { return 0; }
+  virtual unsigned short Command()  { return m_nCommand; }
+  virtual unsigned short SubCommand() { return 0; }
 protected:
   virtual unsigned long getSize()	{ return 1; }
 
@@ -267,18 +274,21 @@ class CPU_Register : public CPacketUdp
 {
 public:
   CPU_Register(const char *_szPasswd);
+  virtual ~CPU_Register();
 };
 #elif ICQ_VERSION > 6
 class CPU_RegisterFirst : public CSrvPacketTcp
 {
 public:
   CPU_RegisterFirst();
+  virtual ~CPU_RegisterFirst();
 };
 
 class CPU_Register : public CPU_CommonFamily
 {
 public:
   CPU_Register(const char *_szPasswd);
+  virtual ~CPU_Register();
 };
 #endif
 
@@ -287,6 +297,7 @@ class CPU_VerifyRegistration : public CPU_CommonFamily
 {
 public:
   CPU_VerifyRegistration();
+  virtual ~CPU_VerifyRegistration();
 };
 
 //-----SendVerification--------------------------------------------------------
@@ -294,6 +305,7 @@ class CPU_SendVerification : public CPU_CommonFamily
 {
 public:
   CPU_SendVerification(const char *, const char *);
+  virtual ~CPU_SendVerification();
 };
 
 //-----ImICQ------------------------------------------------------------------
@@ -370,10 +382,10 @@ class CPU_AddPDINFOToServerList : public CPU_CommonFamily
 {
 public:
   CPU_AddPDINFOToServerList();
-  
+
   unsigned short GetSID()   { return m_nSID; }
   unsigned short GetGSID()  { return m_nGSID; }
-  
+
 protected:
   unsigned short m_nSID,
                  m_nGSID;
@@ -389,7 +401,7 @@ public:
 
   unsigned short GetSID()   { return m_nSID; }
   unsigned short GetGSID()  { return m_nGSID; }
-  
+
 protected:
   unsigned short m_nSID,
                  m_nGSID;
@@ -406,7 +418,7 @@ public:
 //-----ClearServerList----------------------------------------------------------
 class CPU_ClearServerList : public CPU_CommonFamily
 {
- public:
+public:
   CPU_ClearServerList(UserStringList &, unsigned short);
 };
 
@@ -429,20 +441,20 @@ public:
 class CPU_SetStatus : public CPU_CommonFamily
 {
 public:
-   CPU_SetStatus(unsigned long _nNewStatus);
+  CPU_SetStatus(unsigned long _nNewStatus);
 
 private:
-   unsigned long m_nNewStatus;
+  unsigned long m_nNewStatus;
 };
 
 class CPU_SetStatusFamily : public CPU_CommonFamily
 {
 public:
-   CPU_SetStatusFamily();
+  CPU_SetStatusFamily();
 
 protected:
-   void InitBuffer();
-   unsigned long m_nNewStatus;
+  void InitBuffer();
+  unsigned long m_nNewStatus;
 };
 
 class CPU_SetLogonStatus : public CPU_SetStatusFamily
@@ -489,7 +501,7 @@ class CPU_RequestSysMsg : public CPU_CommonFamily
 {
 public:
    CPU_RequestSysMsg();
-   virtual const unsigned short SubCommand()   { return m_nMetaCommand; }
+   virtual unsigned short SubCommand()   { return m_nMetaCommand; }
 
 protected:
    unsigned short m_nMetaCommand;
@@ -500,7 +512,7 @@ class CPU_SysMsgDoneAck : public CPU_CommonFamily
 {
 public:
   CPU_SysMsgDoneAck(unsigned short nId);
-  virtual const unsigned short SubCommand()   { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()   { return m_nMetaCommand; }
 
 protected:
   unsigned short m_nMetaCommand;
@@ -554,7 +566,7 @@ public:
                    const char *szState, unsigned short nCountryCode,
                    const char *szCoName, const char *szCoDept,
                    const char *szCoPos, const char *szKeyword, bool bOnlineOnly);
-   virtual const unsigned short SubCommand()   { return m_nMetaCommand; }
+   virtual unsigned short SubCommand()   { return m_nMetaCommand; }
    unsigned long Uin()  { return 0; }
    void PackSearch(unsigned short nCmd, const char *szField);
 protected:
@@ -567,7 +579,7 @@ class CPU_SearchByUin : public CPU_CommonFamily
 {
 public:
    CPU_SearchByUin(unsigned long nUin);
-   virtual const unsigned short SubCommand()   { return m_nMetaCommand; }
+   virtual unsigned short SubCommand()   { return m_nMetaCommand; }
 protected:
    unsigned long m_nMetaCommand;
 };
@@ -703,7 +715,7 @@ class CPU_InfoPluginReq : public CPU_PluginMessage
 public:
   CPU_InfoPluginReq(ICQUser *u, const char *GUID, unsigned long nTime);
   virtual const char *RequestGUID() { return m_ReqGUID; }
-  virtual const unsigned short ExtraInfo() { return ServerInfoPluginRequest; }
+  virtual unsigned short ExtraInfo() { return ServerInfoPluginRequest; }
 
 protected:
   char m_ReqGUID[GUID_LENGTH];
@@ -714,7 +726,7 @@ class CPU_StatusPluginReq : public CPU_PluginMessage
 {
 public:
   CPU_StatusPluginReq(ICQUser *u, const char *GUID, unsigned long nTime);
-  virtual const unsigned short ExtraInfo() { return ServerStatusPluginRequest; }
+  virtual unsigned short ExtraInfo() { return ServerStatusPluginRequest; }
   virtual const char *RequestGUID() { return m_ReqGUID; }
 
 protected:
@@ -751,7 +763,7 @@ class CPU_FileTransfer : public CPU_AdvancedMessage, public CPX_FileTransfer
 {
 public:
   CPU_FileTransfer(ICQUser *, ConstFileList &lFileList, const char *_szFile,
-		   const char *_szDesc, unsigned short nLevel, bool bICBM);
+                   const char *_szDesc, unsigned short nLevel, bool bICBM);
 };
 
 //-----NoManager--------------------------------------------------------
@@ -836,7 +848,6 @@ class CPU_InfoPluginListResp : public CPU_AckThroughServer
 public:
   CPU_InfoPluginListResp(ICQUser *u, unsigned long nMsgID1,
                          unsigned long nMsgID2, unsigned short nSequence);
-
 };
 
 //-----InfoPhoneBookResp-------------------------------------------------------
@@ -877,7 +888,7 @@ class CPU_SendSms : public CPU_CommonFamily
 {
 public:
    CPU_SendSms(const char *szNumber, const char *szMessage);
-   virtual const unsigned short SubCommand() { return m_nMetaCommand; }
+   virtual unsigned short SubCommand() { return m_nMetaCommand; }
 protected:
    unsigned long m_nMetaCommand;
 };
@@ -919,7 +930,7 @@ class CPU_SetRandomChatGroup : public CPU_CommonFamily
 public:
   CPU_SetRandomChatGroup(unsigned long nGroup);
   unsigned long Group() { return m_nGroup; }
-  virtual const unsigned short SubCommand() { return m_nMetaCommand; }
+  virtual unsigned short SubCommand() { return m_nMetaCommand; }
 protected:
   unsigned long m_nGroup;
   unsigned long m_nMetaCommand;
@@ -932,7 +943,7 @@ class CPU_RandomChatSearch : public CPU_CommonFamily
 {
 public:
   CPU_RandomChatSearch(unsigned long nGroup);
-  virtual const unsigned short SubCommand() { return m_nMetaCommand; }
+  virtual unsigned short SubCommand() { return m_nMetaCommand; }
 protected:
   unsigned long m_nMetaCommand;
 };
@@ -956,7 +967,7 @@ public:
                           const char *szZipCode,
                           unsigned short nCountryCode,
                           bool bHideEmail);
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -985,7 +996,7 @@ class CPU_Meta_SetEmailInfo : public CPU_CommonFamily
 public:
   CPU_Meta_SetEmailInfo(const char *szEmailSecondary,
                         const char *szEmailOld);
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -1009,7 +1020,7 @@ public:
                        char nLanguage1,
                        char nLanguage2,
                        char nLanguage3);
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -1032,7 +1043,7 @@ class CPU_Meta_SetInterestsInfo : public CPU_CommonFamily
 public:
   CPU_Meta_SetInterestsInfo(const ICQUserCategory* interests);
   ~CPU_Meta_SetInterestsInfo();
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -1049,7 +1060,7 @@ public:
   CPU_Meta_SetOrgBackInfo(const ICQUserCategory* orgs,
                           const ICQUserCategory* background);
   ~CPU_Meta_SetOrgBackInfo();
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -1075,7 +1086,7 @@ public:
                        const char *szPosition,
                        unsigned short nCompanyOccupation,
                        const char *szHomepage);
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -1101,8 +1112,8 @@ class CPU_Meta_SetAbout : public CPU_CommonFamily
 {
 public:
   CPU_Meta_SetAbout(const char *szAbout);
-  ~CPU_Meta_SetAbout();
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual ~CPU_Meta_SetAbout();
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 protected:
   unsigned short m_nMetaCommand;
 
@@ -1130,13 +1141,12 @@ class CPU_SetPassword : public CPU_CommonFamily
 {
 public:
   CPU_SetPassword(const char *szPassword);
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
   unsigned long Uin()	{ return 0; }
 protected:
   unsigned short m_nMetaCommand;
-	
-	char *m_szPassword;
-	
+  char *m_szPassword;
+
 friend class CICQDaemon;
 };
 
@@ -1148,7 +1158,7 @@ public:
   CPU_Meta_SetSecurityInfo(bool bAuthorization,
                            bool bHideIp,
                            bool bWebAware);
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
 
   bool Authorization()  { return m_nAuthorization == 0; }
   bool HideIp()         { return m_nHideIp == 1; }
@@ -1166,8 +1176,8 @@ class CPU_Meta_RequestAllInfo : public CPU_CommonFamily
 {
 public:
   CPU_Meta_RequestAllInfo(const char *_szId);
-  virtual ~CPU_Meta_RequestAllInfo() { free(m_szId); }
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual ~CPU_Meta_RequestAllInfo();
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
   const char *Id()  {  return m_szId; }
 protected:
   unsigned short m_nMetaCommand;
@@ -1180,8 +1190,8 @@ class CPU_Meta_RequestBasicInfo : public CPU_CommonFamily
 {
 public:
   CPU_Meta_RequestBasicInfo(const char *_szId);
-  virtual ~CPU_Meta_RequestBasicInfo() { free(m_szId); }
-  virtual const unsigned short SubCommand()  { return m_nMetaCommand; }
+  virtual ~CPU_Meta_RequestBasicInfo();
+  virtual unsigned short SubCommand()  { return m_nMetaCommand; }
   const char *Id()  {  return m_szId; }
 protected:
   unsigned short m_nMetaCommand;
@@ -1197,10 +1207,10 @@ void Encrypt_Client(CBuffer *pkt, unsigned long version);
 class CPacketTcp_Handshake : public CPacket
 {
 public:
-  virtual const unsigned short Sequence()   { return 0; }
-  virtual const unsigned short SubSequence()   { return 0; }
-  virtual const unsigned short Command()    { return ICQ_CMDxTCP_HANDSHAKE; }
-  virtual const unsigned short SubCommand() { return 0; }
+  virtual unsigned short Sequence()   { return 0; }
+  virtual unsigned short SubSequence()   { return 0; }
+  virtual unsigned short Command()    { return ICQ_CMDxTCP_HANDSHAKE; }
+  virtual unsigned short SubCommand() { return 0; }
 };
 
 //-----PacketTcp_Handshake------------------------------------------------------
@@ -1276,7 +1286,7 @@ public:
   char Mode()  { return m_nMode; }
   unsigned long SessionId() { return m_nSessionId; }
   unsigned long Id() { return m_nId; }
-  
+
 protected:
   char m_nHandshake;
   unsigned short m_nVersionMajor;
@@ -1304,7 +1314,7 @@ public:
   CPacketTcp_Handshake_Confirm(unsigned char nChannel, unsigned short nSequence);
   CPacketTcp_Handshake_Confirm(CBuffer *inbuf);
 
-  virtual const unsigned char Channel() { return m_nChannel; }
+  virtual unsigned char Channel() { return m_nChannel; }
   unsigned long Id() { return m_nId; }
 protected:
   unsigned char m_nChannel;
@@ -1319,10 +1329,10 @@ public:
    virtual ~CPacketTcp();
 
    virtual CBuffer *Finalize(INetSocket *);
-   virtual const unsigned short Sequence()   { return m_nSequence; }
-   virtual const unsigned short SubSequence()   { return 0; }
-   virtual const unsigned short Command()    { return m_nCommand; }
-   virtual const unsigned short SubCommand() { return m_nSubCommand; }
+   virtual unsigned short Sequence()   { return m_nSequence; }
+   virtual unsigned short SubSequence()   { return 0; }
+   virtual unsigned short Command()    { return m_nCommand; }
+   virtual unsigned short SubCommand() { return m_nSubCommand; }
 
    char *LocalPortOffset()  {  return m_szLocalPortOffset; }
    unsigned short Level()  { return m_nLevel; }
@@ -1352,7 +1362,7 @@ protected:
    unsigned short m_nSequence;
    bool           m_bPluginReq;
    size_t         m_nMsgLen;
-   
+
    char *m_szLocalPortOffset;
    unsigned short m_nLevel;
    unsigned short m_nVersion;
@@ -1452,6 +1462,7 @@ class CPT_Ack : public CPacketTcp
 protected:
   CPT_Ack(unsigned short _nSubCommand, unsigned short _nSequence,
      bool _bAccept, bool _bUrgent, ICQUser *_cUser);
+  virtual ~CPT_Ack();
 };
 
 
@@ -1613,7 +1624,7 @@ class CPT_PluginError : public CPacketTcp
 public:
    CPT_PluginError(ICQUser *_cUser, unsigned short nSequence,
      unsigned char nChannel);
-   virtual const unsigned char Channel() { return m_nChannel; }
+   virtual unsigned char Channel() { return m_nChannel; }
 
 protected:
    unsigned char m_nChannel;
@@ -1624,9 +1635,9 @@ class CPT_InfoPluginReq : public CPacketTcp
 {
 public:
    CPT_InfoPluginReq(ICQUser *_cUser, const char *GUID, unsigned long int nTime);
-   virtual const unsigned char Channel()   { return ICQ_CHNxINFO; }
+   virtual unsigned char Channel()   { return ICQ_CHNxINFO; }
    virtual const char *RequestGUID()        { return m_ReqGUID; }
-   virtual const unsigned short ExtraInfo() { return DirectInfoPluginRequest; }
+   virtual unsigned short ExtraInfo() { return DirectInfoPluginRequest; }
 
 protected:
    char m_ReqGUID[GUID_LENGTH];
@@ -1637,7 +1648,7 @@ class CPT_InfoPhoneBookResp : public CPacketTcp
 {
 public:
    CPT_InfoPhoneBookResp(ICQUser *_cUser, unsigned short nSequence);
-   virtual const unsigned char Channel() { return ICQ_CHNxINFO; }
+   virtual unsigned char Channel() { return ICQ_CHNxINFO; }
 };
 
 //-----Response to picture request----------------------------------------------
@@ -1645,7 +1656,7 @@ class CPT_InfoPictureResp : public CPacketTcp
 {
 public:
    CPT_InfoPictureResp(ICQUser *_cUser, unsigned short nSequence);
-   virtual const unsigned char Channel() { return ICQ_CHNxINFO; }
+   virtual unsigned char Channel() { return ICQ_CHNxINFO; }
 };
 
 //----Response to info plugin list request--------------------------------------
@@ -1653,7 +1664,7 @@ class CPT_InfoPluginListResp : public CPacketTcp
 {
 public:
    CPT_InfoPluginListResp(ICQUser *_cUser, unsigned short nSequence);
-   virtual const unsigned char Channel() { return ICQ_CHNxINFO; }
+   virtual unsigned char Channel() { return ICQ_CHNxINFO; }
 };
 
 //----Send status plugin request------------------------------------------------
@@ -1661,8 +1672,8 @@ class CPT_StatusPluginReq : public CPacketTcp
 {
 public:
    CPT_StatusPluginReq(ICQUser *_cUser, const char *GUID, unsigned long nTime);
-   virtual const unsigned char  Channel()   { return ICQ_CHNxSTATUS; }
-   virtual const unsigned short ExtraInfo() { return DirectStatusPluginRequest;}
+   virtual unsigned char  Channel()   { return ICQ_CHNxSTATUS; }
+   virtual unsigned short ExtraInfo() { return DirectStatusPluginRequest;}
    virtual const char *RequestGUID() { return m_ReqGUID; }
 
 protected:
@@ -1674,7 +1685,7 @@ class CPT_StatusPluginListResp : public CPacketTcp
 {
 public:
   CPT_StatusPluginListResp(ICQUser *_cUser, unsigned short nSequence);
-  virtual const unsigned char  Channel()   { return ICQ_CHNxSTATUS; }
+  virtual unsigned char  Channel()   { return ICQ_CHNxSTATUS; }
 };
 
 //----Response to status request------------------------------------------------
@@ -1683,7 +1694,7 @@ class CPT_StatusPluginResp : public CPacketTcp
 public:
   CPT_StatusPluginResp(ICQUser *_cUser, unsigned short nSequence,
                        unsigned long nStatus);
-  virtual const unsigned char  Channel()   { return ICQ_CHNxSTATUS; }
+  virtual unsigned char  Channel()   { return ICQ_CHNxSTATUS; }
 };
 
 #endif
