@@ -2,7 +2,9 @@
 #include "config.h"
 #endif
 
-#include <stdio.h>
+#include <cstdio>
+#include <cstring>
+#include <cstdlib>
 #include <unistd.h>
 #include "licq_plugin.h"
 #include "forwarder.h"
