@@ -28,6 +28,7 @@
 #include <openssl/md5.h>
 #include <unistd.h>
 
+#include <cassert>
 #include <string>
 #include <list>
 #include <vector>
@@ -366,7 +367,7 @@ void CMSN::ProcessServerPacket(CMSNBuffer *packet)
         if (*it && strcmp(strUser.c_str(), (*it)->m_szUser) == 0)
         {
           gLog.Info("%sRemoving connection attempt to %s.\n", L_MSNxSTR, strUser.c_str());
-          SStartMessage *pStart = (*it);
+//          SStartMessage *pStart = (*it);
           m_lStart.erase(it);
           break;
         }
@@ -489,6 +490,13 @@ void CMSN::ProcessServerPacket(CMSNBuffer *packet)
     {
       m_bCanPing = true;
     }
+    else if (strCmd == "NOT")
+    {
+      // For the moment, skip the notification... consider it spam from MSN
+      unsigned long nSize = packet->GetParameterUnsignedLong(); // size
+      packet->SkipRN(); // Skip \r\n
+      packet->Skip(nSize);
+    }
     else
     {
       gLog.Warn("%sUnhandled command (%s).\n", L_MSNxSTR, strCmd.c_str());
@@ -503,6 +511,7 @@ void CMSN::SendPacket(CMSNPacket *p)
 {
   INetSocket *s = gSocketMan.FetchSocket(m_nServerSocket);
   SrvSocket *sock = static_cast<SrvSocket *>(s);
+  assert(sock != NULL);
   if (!sock->SendRaw(p->getBuffer()))
     MSNLogoff(true);
   else
@@ -688,6 +697,10 @@ void CMSN::MSNUnblockUser(char *szUser)
 
 void CMSN::MSNGetDisplayPicture(const string &strUser, const string &strMSNObject)
 {
+  // If we are invisible, this will result in an error, so don't allow it
+  if (m_nStatus & ICQ_STATUS_FxPRIVATE)
+    return;
+
   char *szUser = const_cast<char *>(strUser.c_str());
   CMSNPacket *pGetMSNDP = new CPS_MSNInvitation(szUser,
 						m_szUserName,
