@@ -1,4 +1,22 @@
 // -*- c-basic-offset: 2 -*-
+/*
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 1999-2006 Licq developers
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -26,11 +44,13 @@
 #include <qdatetime.h>
 #include <qlayout.h>
 #include <qheader.h>
+#include <qstringlist.h>
 #include <ctype.h>
 #include <algorithm>
 
 #include "licq_history.h"
 #include "licq_events.h"
+#include "licq_user.h"
 #include "mainwin.h"
 #include "eventdesc.h"
 #include "ewidgets.h"
@@ -56,7 +76,6 @@ bool QueryUser(QWidget *q, QString szQuery, QString szBtn1, QString szBtn2, bool
   bool result;
 
 #ifdef USE_KDE
-#if KDE_VERSION >= 290
   result = ( KMessageBox::questionYesNo(q, szQuery, QMessageBox::tr("Licq Question"), szBtn1, szBtn2, QString::null, false) == KMessageBox::Yes);
   // The user must confirm his decision!
   if(result == true && bConfirmYes && szConfirmYes)
@@ -64,20 +83,12 @@ bool QueryUser(QWidget *q, QString szQuery, QString szBtn1, QString szBtn2, bool
   else if(result == false && bConfirmNo && szConfirmNo)
     result = ( KMessageBox::questionYesNo(q, szConfirmNo, QMessageBox::tr("Licq Question"), QMessageBox::tr("Yes"), QMessageBox::tr("No"), QString::null, false) == KMessageBox::Yes);
 #else
-  result = ( KMessageBox::questionYesNo(q, szQuery, QMessageBox::tr("Licq Question"), szBtn1, szBtn2, false) == KMessageBox::Yes);
+  result = ( QMessageBox::question(q, QMessageBox::tr("Licq Question"), szQuery, szBtn1, szBtn2) == 0);
   // The user must confirm his decision!
   if(result == true && bConfirmYes && szConfirmYes)
-    result = ( KMessageBox::questionYesNo(q, szConfirmYes, QMessageBox::tr("Licq Question"), QMessageBox::tr("Yes"), QMessageBox::tr("No"), false) == KMessageBox::Yes);
+    result = ( QMessageBox::question(q, QMessageBox::tr("Licq Question"), szConfirmYes, QMessageBox::tr("Yes"), QMessageBox::tr("No")) == 0);
   else if(result == false && bConfirmNo && szConfirmNo)
-    result = ( KMessageBox::questionYesNo(q, szConfirmNo, QMessageBox::tr("Licq Question"), QMessageBox::tr("Yes"), QMessageBox::tr("No"), false) == KMessageBox::Yes);
-#endif
-#else
-  result = ( QMessageBox::information(q, QMessageBox::tr("Licq Question"), szQuery, szBtn1, szBtn2) == 0);
-  // The user must confirm his decision!
-  if(result == true && bConfirmYes && szConfirmYes)
-    result = ( QMessageBox::information(q, QMessageBox::tr("Licq Question"), szConfirmYes, QMessageBox::tr("Yes"), QMessageBox::tr("No")) == 0);
-  else if(result == false && bConfirmNo && szConfirmNo)
-    result = ( QMessageBox::information(q, QMessageBox::tr("Licq Question"), szConfirmNo, QMessageBox::tr("Yes"), QMessageBox::tr("No")) == 0);
+    result = ( QMessageBox::question(q, QMessageBox::tr("Licq Question"), szConfirmNo, QMessageBox::tr("Yes"), QMessageBox::tr("No")) == 0);
 #endif
   
   return result;
@@ -86,7 +97,7 @@ bool QueryUser(QWidget *q, QString szQuery, QString szBtn1, QString szBtn2, bool
 
 int QueryUser(QWidget *q, QString szQuery, QString szBtn1, QString szBtn2, QString szBtn3)
 {
-  return ( QMessageBox::information(q, QMessageBox::tr("Licq Question"), szQuery, szBtn1, szBtn2, szBtn3));
+  return ( QMessageBox::question(q, QMessageBox::tr("Licq Question"), szQuery, szBtn1, szBtn2, szBtn3));
 }
 
 
@@ -111,12 +122,6 @@ CELabel::CELabel(bool _bTransparent, QPopupMenu *m, QWidget *parent, char *name)
 {
   mnuPopUp = m;
   m_bTransparent = _bTransparent;
-  if (_bTransparent)
-  {
-#if QT_VERSION < 300
-    setAutoMask(true);
-#endif
-  }
 }
 
 
@@ -189,13 +194,8 @@ void CELabel::setNamedFgColor(char *theColor)
    if (!c.isValid()) return;
 
    QPalette pal(palette());
-#if QT_VERSION >= 210
    pal.setColor(QPalette::Active, QColorGroup::Foreground, c);
    pal.setColor(QPalette::Inactive, QColorGroup::Foreground, c);
-#else
-   pal.setColor(QPalette::Active, QColorGroup::Text, c);
-   pal.setColor(QPalette::Normal, QColorGroup::Text, c);
-#endif
 
    setPalette(pal);
 }
@@ -210,22 +210,13 @@ void CELabel::setNamedBgColor(char *theColor)
    QPalette pal(palette());
 // Since Qt sucks we have to use this cheap hack instead of the documented
 // and correct way to set the color
-#if QT_VERSION < 300
-   QColorGroup normal(pal.normal());
-#else
-   QColorGroup normal(pal.active()); 
-#endif
+   QColorGroup normal(pal.active());
    QColorGroup newNormal(normal.foreground(), c, normal.light(), normal.dark(),
                          normal.mid(), normal.text(), normal.base());
    pal = QPalette(newNormal, newNormal, newNormal);
 #if 0
-#if QT_VERSION >= 210
    pal.setColor(QPalette::Active, QColorGroup::Background, c);
    pal.setColor(QPalette::Inactive, QColorGroup::Background, c);
-#else
-   pal.setColor(QPalette::Active, QColorGroup::Background, c);
-   pal.setColor(QPalette::Normal, QColorGroup::Background, c);
-#endif
 #endif
 
    setPalette(pal);
@@ -239,7 +230,7 @@ void CELabel::drawContents(QPainter* p)
   if (m_lPixmaps.size())
   {
     list<QPixmap>::iterator it;
-    int i = 2;
+    int i = indent();
     for (it = m_lPixmaps.begin(); it != m_lPixmaps.end(); it++)
     {
       p->drawPixmap(i, height() / 2 - it->height() / 2, *it);
@@ -252,7 +243,6 @@ void CELabel::drawContents(QPainter* p)
 
 void CELabel::resizeEvent (QResizeEvent *)
 {
-#if QT_VERSION >= 300
   if (paletteBackgroundPixmap() != NULL)
   {
     // Scale it if it is not transparent
@@ -264,18 +254,6 @@ void CELabel::resizeEvent (QResizeEvent *)
       setPaletteBackgroundPixmap(pm);
     }
   }
-#else 
-  // Resize the background pixmap properly
-  if (autoMask()) updateMask();
-
-  if (backgroundPixmap() != NULL)
-  {
-    QImage im = (backgroundPixmap()->convertToImage()).smoothScale(width(), height());
-    QPixmap pm;
-    pm.convertFromImage(im);
-    setBackgroundPixmap(pm);
-  }
-#endif
 }
 
 void CELabel::mousePressEvent(QMouseEvent* e)
@@ -389,11 +367,7 @@ void CEButton::setNamedFgColor(char *theColor)
    if (theColor == NULL) return;
 
    QPalette pal(palette());
-#if QT_VERSION < 300
-   QColorGroup normal(pal.normal());
-#else
    QColorGroup normal(pal.active());
-#endif
    QColorGroup newNormal(normal.foreground(), normal.background(), normal.light(), normal.dark(),
                          normal.mid(), QColor(theColor), normal.base());
    setPalette(QPalette(newNormal, pal.disabled(), newNormal));
@@ -404,11 +378,7 @@ void CEButton::setNamedBgColor(char *theColor)
    if (theColor == NULL) return;
 
    QPalette pal(palette());
-#if QT_VERSION < 300
-   QColorGroup normal(pal.normal());
-#else
    QColorGroup normal(pal.active());
-#endif
    QColorGroup newNormal(normal.foreground(), QColor(theColor), normal.light(), normal.dark(),
                          normal.mid(), normal.text(), normal.base());
    setPalette(QPalette(newNormal, pal.disabled(), newNormal));
@@ -423,11 +393,7 @@ CEComboBox::CEComboBox(bool _bAppearEnabledAlways, QWidget *parent, char *name)
    if (m_bAppearEnabledAlways)
    {
       QPalette pal(palette());
-#if QT_VERSION < 300
-      setPalette(QPalette(pal.normal(), pal.normal(), pal.normal()));
-#else
       setPalette(QPalette(pal.active(), pal.active(), pal.active()));
-#endif
    }
 }
 
@@ -437,11 +403,7 @@ void CEComboBox::setNamedFgColor(char *theColor)
    if (theColor == NULL) return;
 
    QPalette pal(palette());
-#if QT_VERSION < 300
-   QColorGroup normal(pal.normal());
-#else
    QColorGroup normal(pal.active());
-#endif
    QColorGroup newNormal(normal.foreground(), normal.background(), normal.light(), normal.dark(),
                          normal.mid(), QColor(theColor), normal.base());
    setPalette(QPalette(newNormal, pal.disabled(), newNormal));
@@ -453,11 +415,7 @@ void CEComboBox::setNamedBgColor(char *theColor)
    if (theColor == NULL) return;
 
    QPalette pal(palette());
-#if QT_VERSION < 300
-   QColorGroup normal(pal.normal());
-#else
    QColorGroup normal(pal.active());
-#endif
    QColorGroup newNormal(normal.foreground(), normal.background(), normal.light(), normal.dark(),
                          normal.mid(), normal.text(), QColor(theColor));
    setPalette(QPalette(newNormal, pal.disabled(), newNormal));
@@ -540,8 +498,8 @@ void CETabBar::paintLabel(QPainter* p, const QRect &br,
     
     p->drawPixmap(br.left() + 2 + xoff, br.center().y()-pixh/2 + yoff, pixmap);
 #else
-    p->drawPixmap(br.left() + 2 + ((selected == TRUE) ? 0 : 2),
-                  br.center().y()-pixh/2 + ((selected == TRUE) ? 0 : 2),
+    p->drawPixmap(br.left() + 2 + ((selected == true) ? 0 : 2),
+                  br.center().y()-pixh/2 + ((selected == true) ? 0 : 2),
                   pixmap);
 #endif
   }
@@ -571,7 +529,7 @@ void CETabBar::paintLabel(QPainter* p, const QRect &br,
 
 void CETabBar::wheelEvent(QWheelEvent *e)
 {
-  if (count() <= 1)
+  if (count() <= 1 || !hasMouse())
   {
     e->ignore();
     return;
@@ -582,13 +540,43 @@ void CETabBar::wheelEvent(QWheelEvent *e)
   else
     setNextTab();
 }
-         
+
+void CETabBar::mousePressEvent(QMouseEvent* e)
+{
+  if ((e->button() & Qt::MouseButtonMask) == Qt::MidButton)
+  {
+    QTab* tab = selectTab(e->pos());
+    if (tab != 0)
+      clickedTab = indexOf(tab->identifier());
+  }
+
+  QTabBar::mousePressEvent(e);
+}
+
+void CETabBar::mouseReleaseEvent(QMouseEvent* e)
+{
+  if ((e->button() & Qt::MouseButtonMask) == Qt::MidButton)
+  {
+    QTab* tab = selectTab(e->pos());
+    if (tab != 0)
+    {
+      int t = indexOf(tab->identifier());
+      if (t == clickedTab)
+        emit middleClick(t);
+    }
+  }
+
+  clickedTab = -1;
+  QTabBar::mouseReleaseEvent(e);
+}
 
 //CETabWidget
 CETabWidget::CETabWidget(QWidget *parent, const char *name, WFlags f)
   : QTabWidget(parent, name, f)
 {
-  setTabBar(new CETabBar(this, "tabbar"));
+  CETabBar* tb = new CETabBar(this, "tabbar");
+  setTabBar(tb);
+  connect(tb, SIGNAL(middleClick(int)), this, SLOT(slot_middleClick(int)));
 }
 
 void CETabWidget::setTabColor(QWidget *w, const QColor &color)
@@ -631,16 +619,19 @@ void CETabWidget::wheelEvent(QWheelEvent *e)
     setNextPage();
 }
 
+void CETabWidget::slot_middleClick(int t)
+{
+  QWidget* p = page(t);
+  if (p)
+    emit middleClick(p);
+}
+
 //-----CInfoField::constructor--------------------------------------------------
 CInfoField::CInfoField(QWidget *parent, bool readonly)
   : QLineEdit(parent)
 {
   baseRO = palette().disabled().base();
-#if QT_VERSION < 300
-  baseRW = palette().normal().base();
-#else
   baseRW = palette().active().base();
-#endif
 
   // Set colors
   SetReadOnly(readonly);
@@ -648,15 +639,6 @@ CInfoField::CInfoField(QWidget *parent, bool readonly)
 
 void CInfoField::SetReadOnly(bool b)
 {
-#if QT_VERSION < 300
-  QColorGroup cg(palette().normal().foreground(),
-                 palette().normal().background(),
-                 palette().normal().light(),
-                 palette().normal().dark(),
-                 palette().normal().mid(),
-                 palette().normal().text(),
-                 b ? baseRO : baseRW);
-#else
   QColorGroup cg(palette().active().foreground(),
                  palette().active().background(),
                  palette().active().light(),
@@ -664,7 +646,6 @@ void CInfoField::SetReadOnly(bool b)
                  palette().active().mid(),
                  palette().active().text(),
                  b ? baseRO : baseRW);
-#endif
 
   setPalette(QPalette(cg, palette().disabled(), cg));
   setReadOnly(b);
@@ -707,65 +688,127 @@ void CInfoField::keyPressEvent(QKeyEvent *e)
   QLineEdit::keyPressEvent(e);
 }
 
-
 // -----------------------------------------------------------------------------
 
-CHistoryWidget::CHistoryWidget(QWidget* parent, const char* name)
-  : MLView(parent, name)
+CTimeZoneField::CTimeZoneField(QWidget *parent)
+    : QSpinBox(-24, 24, 1, parent)
 {
-#if QT_VERSION >= 300
-  setTextFormat(RichText);
-#endif
-};
+  // The world is round so let timezones wrap
+  setWrapping(true);
 
-// -----------------------------------------------------------------------------
+  // Plus and minus seems more fitting than up and down
+  setButtonSymbols(QSpinBox::PlusMinus);
 
-#if QT_VERSION < 300
-void CHistoryWidget::paintCell(QPainter* p, int row, int col)
-{
-  QPalette& pal = const_cast<QPalette&>(palette());
+  // Force the input to be in format GMT+500, GMT-1030, etc...
+  setPrefix("GMT");
+  setValidator(new QRegExpValidator(QRegExp("^[\\+\\-](1[012]|\\d)[03]0$|^Unknown$"), this));
 
-  QString s = stringShown(row);
-  bool bold = (s[0] == '\001' || s[0] == '\002');
-  if(bold ^ p->font().bold()) {
-    QFont f(p->font());
-    f.setBold(bold);
-    p->setFont(f);
-  }
-
-  int i= row;
-  pal.setColor(QColorGroup::Text, Qt::blue);
-  while(i >= 0)
-  {
-    QString s2 = stringShown(i--);
-    if (s2[0] == '\002')  break;
-    if(s2[0] == '\001')
-    {
-      pal.setColor(QColorGroup::Text, Qt::red);
-      break;
-    }
-  }
-
-  MLView::paintCell(p, row, col);
+  // Allow the value to be undefined as well. This will replace the lowest value (-24)
+  setSpecialValueText(tr("Unknown"));
 }
-#endif
+
+void CTimeZoneField::setData(char data)
+{
+  // The spinbox uses the lowest value to mark the undefined state but the constant is some other value so we need to change it
+  // For all defined values, the sign is inverted
+  setValue(data == TIMEZONE_UNKNOWN ? undefinedValue : static_cast<int>(-data));
+}
+
+char CTimeZoneField::data()
+{
+  int v = value();
+  if (v == undefinedValue)
+    return TIMEZONE_UNKNOWN;
+  return static_cast<char>(-v);
+}
+
+QString CTimeZoneField::mapValueToText(int v)
+{
+  // The internal value in the spinbox is 30min intervals so convert it to something more readable
+  return QString("%1%2%3").arg(v < 0 ? "-" : "+").arg(abs(v) / 2).arg(v % 2 ? "30" : "00");
+}
+
+int CTimeZoneField::mapTextToValue(bool *ok)
+{
+  // The user entered something so now we must try and convert it back to the internal int
+  QRegExp rx("^(\\+|-)(\\d+)(0|3)0$");
+  if (rx.search(cleanText()) == -1)
+  {
+    *ok = false;
+    return 0;
+  }
+  int ret = rx.cap(2).toInt() * 2;
+  if (rx.cap(3) == "3")
+    ret++;
+  if (rx.cap(1) == "-")
+    ret = -ret;
+  *ok = true;
+  return ret;
+}
+
 
 //- Message View Widget ---------------------------------------------------------
-CMessageViewWidget::CMessageViewWidget(const char *szId, unsigned long nPPID,
-  CMainWindow *m, QWidget* parent, const char * name)
-  : CHistoryWidget(parent, name)
+
+QStringList CMessageViewWidget::getStyleNames(bool includeHistoryStyles)
 {
+  static const char *const styleNames[] = {
+    QT_TR_NOOP("Default"),
+    QT_TR_NOOP("Compact"),
+    QT_TR_NOOP("Tiny"),
+    QT_TR_NOOP("Table"),
+    QT_TR_NOOP("Long"),
+    QT_TR_NOOP("Wide")
+  };
+
+  int listLength;
+
+  // Style 5 (Wide) is currently only supported in buffered mode which is not used for chat
+  if(includeHistoryStyles)
+    listLength = 6;
+  else
+    listLength = 5;
+
+  QStringList styleList;
+  for(int i = 0; i < listLength; ++i)
+    styleList.append(tr(styleNames[i]));
+
+  return styleList;
+}
+
+CMessageViewWidget::CMessageViewWidget(const char *szId, unsigned long nPPID,
+  CMainWindow *m, QWidget* parent, const char *name, bool historyMode)
+  : MLView(parent, name)
+{
+  setTextFormat(RichText);
   m_szId = szId ? strdup(szId) : 0;
   m_nPPID = nPPID;
-  m_nMsgStyle = m->m_nMsgStyle;
-  m_bAppendLineBreak = m->m_bAppendLineBreak;
+  if (historyMode)
+  {
+    m_useBuffer = true;
+    m_nMsgStyle = m->m_histMsgStyle;
+    m_nDateFormat = m->m_histDateFormat;
+    m_extraSpacing = m->m_histVertSpacing;
+    m_appendLineBreak = false;
+  }
+  else
+  {
+    m_useBuffer = false;
+    m_nMsgStyle = m->m_chatMsgStyle;
+    m_nDateFormat = m->m_chatDateFormat;
+    m_extraSpacing = m->m_chatVertSpacing;
+    m_appendLineBreak = m->m_chatAppendLineBreak;
+  }
+  m_showNotices = m->m_showNotices;
   m_colorRcv = m->m_colorRcv;
   m_colorSnt = m->m_colorSnt;
   m_colorRcvHistory = m->m_colorRcvHistory;
   m_colorSntHistory = m->m_colorSntHistory;
+  m_colorNotice = m->m_colorNotice;
   setPaletteBackgroundColor(m->m_colorChatBkg);
   mainwin = m;
 
+  clear();
+
 /*
   // add all unread messages.
   vector<CUserEvent*> newEventList;
@@ -785,19 +828,39 @@ CMessageViewWidget::CMessageViewWidget(const char *szId, unsigned long nPPID,
 */
 }
 
-CMessageViewWidget::CMessageViewWidget(unsigned long _nUin, CMainWindow *m, QWidget* parent, const char * name)
-:CHistoryWidget(parent,name)
+CMessageViewWidget::CMessageViewWidget(unsigned long _nUin, CMainWindow *m, QWidget *parent, const char *name, bool historyMode)
+  : MLView(parent,name)
 {
+  setTextFormat(RichText);
   m_nUin= _nUin;
   m_szId = NULL; // avoid desalocation error at destructor
-  m_nMsgStyle = m->m_nMsgStyle;
-  m_bAppendLineBreak = m->m_bAppendLineBreak;
+  if (historyMode)
+  {
+    m_useBuffer = true;
+    m_nMsgStyle = m->m_histMsgStyle;
+    m_nDateFormat = m->m_histDateFormat;
+    m_extraSpacing = m->m_histVertSpacing;
+    m_appendLineBreak = false;
+  }
+  else
+  {
+    m_useBuffer = false;
+    m_nMsgStyle = m->m_chatMsgStyle;
+    m_nDateFormat = m->m_chatDateFormat;
+    m_extraSpacing = m->m_chatVertSpacing;
+    m_appendLineBreak = m->m_chatAppendLineBreak;
+  }
+  m_showNotices = m->m_showNotices;
   m_colorRcv = m->m_colorRcv;
   m_colorSnt = m->m_colorSnt;
   m_colorRcvHistory = m->m_colorRcvHistory;
   m_colorSntHistory = m->m_colorSntHistory;
+  m_colorNotice = m->m_colorNotice;
   setPaletteBackgroundColor(m->m_colorChatBkg);
   mainwin = m;
+
+  clear();
+
 /*
   // add all unread messages.
   vector<CUserEvent*> newEventList;
@@ -831,6 +894,69 @@ void CMessageViewWidget::setOwner(const char *_szId)
   m_szId = strdup(_szId);
 }
 
+void CMessageViewWidget::clear()
+{
+  MLView::clear();
+
+  m_buffer = "";
+
+  switch (m_nMsgStyle)
+  {
+    case 5:
+      // table doesn't work when appending so must buffer when using this style
+      m_buffer.append("<table border=\"0\">");
+      m_useBuffer = true;
+      break;
+  }
+  if (m_useBuffer)
+    m_buffer.prepend("<html><body>");
+}
+
+void CMessageViewWidget::updateContent()
+{
+  if (m_useBuffer)
+    setText(m_buffer);
+}
+
+void CMessageViewWidget::internalAddMsg(QString s)
+{
+  if (m_extraSpacing)
+  {
+    if (m_nMsgStyle != 5)
+    {
+      if (m_useBuffer)
+      {
+        s.prepend("<p>");
+        s.append("</p>");
+      }
+      else
+      {
+        s.append("<br>");
+      }
+    }
+    else
+    {
+      s.append("<tr><td colspan=\"3\"></td></tr>");
+    }
+  }
+
+  if (m_useBuffer)
+  {
+    if (!m_extraSpacing && m_nMsgStyle != 5)
+      s.append("<br>");
+
+    m_buffer.append(s);
+    if (m_appendLineBreak)
+      m_buffer.append("<hr>");
+  }
+  else
+  {
+    append(s);
+    if (m_appendLineBreak)
+      append("<hr>");
+  }
+}
+
 void CMessageViewWidget::addMsg(ICQEvent * _e)
 {
   if (strcmp(_e->Id(), m_szId) == 0 && _e->PPID() == m_nPPID &&
@@ -844,41 +970,55 @@ void CMessageViewWidget::addMsg(direction dir, bool fromHistory, QString eventDe
 {
   QString s;
   QString color;
-  bool bAIM = (m_nPPID == LICQ_PPID) && !isdigit(m_szId[0]);
 
-  if (fromHistory) 
+  if (fromHistory)
+  {
     if (dir == D_RECEIVER) 
       color = m_colorRcvHistory.name();
     else 
-      color = m_colorSntHistory.name();  
+      color = m_colorSntHistory.name();
+  }
   else
+  {
     if (dir == D_RECEIVER) 
       color = m_colorRcv.name();
     else 
-      color = m_colorSnt.name();  
-  
-  /* Remove trailing line breaks. */
-  for (unsigned int i = messageText.length() - 1; i>=0; i--) {
-    if (messageText.at(i) == '\n' || messageText.at(i) == '\r') {
+      color = m_colorSnt.name();
+  }
+
+  // Remove trailing line breaks.
+  for (int i = messageText.length(); i > 0; i--)
+  {
+    if (messageText.at(i - 1) != '\n' && messageText.at(i - 1) != '\r')
+    {
       messageText.truncate(i);
-    } else {
       break;
     }
   }
-     
-  
+
+  // Extract everything inside <body>...</body>
+  // Leaving <html> and <body> messes with our message display
+  QRegExp body("<body[^>]*>(.*)</body>");
+  if (body.search(messageText) != -1)
+    messageText = body.cap(1);
+
+  // Remove all font tags
+  messageText.replace(QRegExp("</?font[^>]*>"), "");
+
+  QString my_date = date.toString( m_nDateFormat );
+
   switch (m_nMsgStyle) {
     case 0:
-      s = QString("<html><body><font color=\"%1\"><b>%2%3 [%4%5%6%7] %8:</b></font><br>")
+      s = QString("<font color=\"%1\"><b>%2%3 [%4%5%6%7] %8:</b></font><br>")
                   .arg(color)
                   .arg(eventDescription)
-                  .arg(date.time().toString())
+                  .arg(my_date)
                   .arg(isDirect ? 'D' : '-')
                   .arg(isMultiRec ? 'M' : '-')
                   .arg(isUrgent ? 'U' : '-')
                   .arg(isEncrypted ? 'E' : '-')
                   .arg(contactName);
-      s.append(QString("<font color=\"%1\">%2</font></body></html>")
+      s.append(QString("<font color=\"%1\">%2</font>")
                       .arg(color)
                       .arg(messageText));
       break;
@@ -886,7 +1026,7 @@ void CMessageViewWidget::addMsg(direction dir, bool fromHistory, QString eventDe
       s = QString("<font color=\"%1\"><b>(%2%3) [%4%5%6%7] %8: </b></font>")
                   .arg(color)
                   .arg(eventDescription)
-                  .arg(date.time().toString())
+                  .arg(my_date)
                   .arg(isDirect ? 'D' : '-')
                   .arg(isMultiRec ? 'M' : '-')
                   .arg(isUrgent ? 'U' : '-')
@@ -895,35 +1035,22 @@ void CMessageViewWidget::addMsg(direction dir, bool fromHistory, QString eventDe
       s.append(QString("<font color=\"%1\">%2</font>")
                       .arg(color)
                       .arg(messageText));
-      if (bAIM)
-      {
-        s.prepend("<html><body>");
-        s.append("</body></html>");
-      }
-
       break;
     case 2:
       s = QString("<font color=\"%1\"><b>%2%3 - %4: </b></font>")
                   .arg(color)
                   .arg(eventDescription)
-                  .arg(date.time().toString())
+                  .arg(my_date)
                   .arg(contactName);
       s.append(QString("<font color=\"%1\">%2</font>")
                       .arg(color)
                       .arg(messageText));
-
-      if (bAIM)
-      {
-        s.prepend("<html><body>");
-        s.append("</body></html>");
-      }
-
       break;  
     case 3:
       s = QString("<table border=\"1\"><tr><td><b><font color=\"%1\">%2%3</font><b><td><b><font color=\"%4\">%5</font></b></font></td>")
                   .arg(color)
                   .arg(eventDescription)
-                  .arg(date.time().toString())
+                  .arg(my_date)
                   .arg(color)
                   .arg(contactName);
       s.append(QString("<td><font color=\"%1\">%2</font></td></tr></table>")
@@ -936,7 +1063,7 @@ void CMessageViewWidget::addMsg(direction dir, bool fromHistory, QString eventDe
                   .arg((dir == D_RECEIVER ? tr("%1 from %2") : tr("%1 to %2")))
                   .arg(eventDescription)
                   .arg(contactName)
-                  .arg(date.toString())
+                  .arg(my_date)
                   .arg(isDirect ? 'D' : '-')
                   .arg(isMultiRec ? 'M' : '-')
                   .arg(isUrgent ? 'U' : '-')
@@ -948,20 +1075,29 @@ void CMessageViewWidget::addMsg(direction dir, bool fromHistory, QString eventDe
       s.append(QString("<font color=\"%1\">%2</font><br><br>")
                   .arg(color)
                   .arg(messageText));
-    break;     
-  }
-  
-  append(s);
-  if (m_bAppendLineBreak) {
-    append("<hr>");
+      break;
+    case 5:
+      // Mode 5 is a table so it cannot be displayed in paragraphs
+      s = QString("<tr><td><nobr><b><font color=\"%1\">%2</font><b></nobr></td>")
+                  .arg(color)
+                  .arg(my_date);
+      s.append(QString("<td><b><font color=\"%3\">%4</font></b></font></td>")
+                       .arg(color)
+                       .arg(contactName));
+      s.append(QString("<td><font color=\"%1\">%2</font></td></tr>")
+                      .arg(color)
+                      .arg(messageText));
+      break;
   }
+
+  internalAddMsg(s);
 }
 
 void CMessageViewWidget::addMsg(CUserEvent* e, const char *_szId, unsigned long _nPPID)
 {
   QDateTime date;
   date.setTime_t(e->Time());
-  QString sd = date.time().toString();
+  QString sd = date.time().toString( m_nDateFormat );
   bool bUseHTML = false;
 
   QString contactName;
@@ -978,14 +1114,14 @@ void CMessageViewWidget::addMsg(CUserEvent* e, const char *_szId, unsigned long
         contactName = QString::fromUtf8(u->GetAlias());
       for (unsigned int x = 0; x < strlen(m_szId); x++)
       {
-        if (!isdigit(m_szId[x]) && m_nPPID == LICQ_PPID)
+        if (!isdigit(m_szId[x]) && m_nPPID == LICQ_PPID && e->Direction() == D_RECEIVER)
         {
           bUseHTML = true;
           break;
         }
       }
+      gUserManager.DropUser(u);
     }
-    gUserManager.DropUser(u);
   }
 
   if (e->Direction() != D_RECEIVER)
@@ -1001,9 +1137,6 @@ void CMessageViewWidget::addMsg(CUserEvent* e, const char *_szId, unsigned long
     }
   }
 
-  QString s;
-
-#if QT_VERSION >= 300
   QString messageText;
   if (e->SubCommand() == ICQ_CMDxSUB_SMS)
      messageText = QString::fromUtf8(e->Text());
@@ -1019,25 +1152,6 @@ void CMessageViewWidget::addMsg(CUserEvent* e, const char *_szId, unsigned long
          e->IsEncrypted(),
          contactName,
          MLView::toRichText(messageText, true, bUseHTML));
-#else
-  QString messageText = codec->toUnicode(e->Text());
-  s.sprintf("%c%s%s [%c%c%c%c] %s:\n%s",
-            (e->Direction() == D_RECEIVER) ? '\001' : '\002',
-            e->SubCommand() == ICQ_CMDxSUB_MSG ? QString("") :
-              (EventDescription(e) + " ").utf8().data(),
-            sd.utf8().data(),
-            e->IsDirect() ? 'D' : '-',
-            e->IsMultiRec() ? 'M' : '-',
-            e->IsUrgent() ? 'U' : '-',
-            e->IsEncrypted() ? 'E' : '-',
-            contactName.utf8().data(),
-            messageText.utf8().data()
-           );
-  append(s);
-#endif
-#if QT_VERSION < 300
-  repaint(false);
-#endif
   GotoEnd();
 
   QWidget *parent = NULL;
@@ -1045,12 +1159,9 @@ void CMessageViewWidget::addMsg(CUserEvent* e, const char *_szId, unsigned long
       parentWidget()->parentWidget() &&
       parentWidget()->parentWidget()->parentWidget())
     parent = parentWidget()->parentWidget()->parentWidget();
-  if (
-#if QT_VERSION >= 300
-      parent && parent->isActiveWindow() &&
+  if (parent && parent->isActiveWindow() &&
       (!mainwin->m_bTabbedChatting || (mainwin->m_bTabbedChatting &&
        mainwin->userEventTabDlg->tabIsSelected(parent))) &&
-#endif
       e->Direction() == D_RECEIVER && e->SubCommand() == ICQ_CMDxSUB_MSG)
   {
     UserSendCommon *s = static_cast<UserSendCommon*>(parent);
@@ -1058,21 +1169,25 @@ void CMessageViewWidget::addMsg(CUserEvent* e, const char *_szId, unsigned long
   }
 }
 
-void CMessageViewWidget::addNotice(QString dateTime, QString messageText)
+void CMessageViewWidget::addNotice(QDateTime dt, QString messageText)
 {
-  QString color = "green";
+  if (!m_showNotices)
+    return;
+
+  QString color = m_colorNotice.name();
   QString s = "";
-  
-  /* Remove trailing line breaks. */
-  for (unsigned int i = messageText.length() - 1; i >= 0; i--)
+  const QString dateTime = dt.toString( m_nDateFormat );
+
+  // Remove trailing line breaks.
+  for (int i = messageText.length(); i > 0; i--)
   {
-    if (messageText.at(i) == '\n' || messageText.at(i) == '\r')
+    if (messageText.at(i - 1) != '\n' && messageText.at(i - 1) != '\r')
+    {
       messageText.truncate(i);
-    else
       break;
+    }
   }
-     
-  
+
   switch (m_nMsgStyle)
   {
     case 1:
@@ -1095,24 +1210,30 @@ void CMessageViewWidget::addNotice(QString dateTime, QString messageText)
                   .arg(messageText);
       break; 
 
+    case 5:
+      s = QString("<tr><td><b><font color=\"%1\">%2</font><b></td><td colspan=\"2\"><b><font color=\"%3\">%4</font></b></font></td></tr>")
+                  .arg(color)
+                  .arg(dateTime)
+                  .arg(color)
+                  .arg(messageText);
+      break;
+
     case 0:
     default:
-      s = QString("<html><body><font color=\"%1\"><b>[%2] %3</b></font><br></body></html>")
+      s = QString("<font color=\"%1\"><b>[%2] %3</b></font><br>")
                   .arg(color)
                   .arg(dateTime)
                   .arg(messageText);
       break;    
   }
-  
-  append(s);
-  if (m_bAppendLineBreak)
-    append("<hr>");
+
+  internalAddMsg(s);
 }
 
 CLicqMessageBox::CLicqMessageBox(QWidget *parent)
   : QDialog(parent, "LicqInfo", false, Qt::WType_Dialog|Qt::WShowModal), m_nUnreadNum(0)
 {
-  setCaption("Licq");
+  setCaption(tr("Licq"));
 
   // Start with no message
   QString msg = "";
@@ -1148,11 +1269,11 @@ CLicqMessageBox::CLicqMessageBox(QWidget *parent)
   // Make the second horizontal layout for the buttons
   QFrame *frmButtons = new QFrame(this);
   QHBoxLayout *lay2 = new QHBoxLayout(frmButtons, 0, 15);
-  m_btnMore = new QPushButton("&List", frmButtons);
+  m_btnMore = new QPushButton(tr("&List"), frmButtons);
   //m_btnMore->setDisabled(true);
-  m_btnNext = new QPushButton("&Next", frmButtons);
+  m_btnNext = new QPushButton(tr("&Next"), frmButtons);
   m_btnNext->setDisabled(true);
-  m_btnClear = new QPushButton("&Ok", frmButtons);
+  m_btnClear = new QPushButton(tr("&Ok"), frmButtons);
   m_btnClear->setDefault(true);
 
   lay2->addWidget(m_btnMore);
@@ -1192,20 +1313,20 @@ void CLicqMessageBox::addMessage(QMessageBox::Icon type, const QString &msg)
   { 
     m_lblIcon->setPixmap(pix);
     m_lblMessage->setText(msg);
-    m_btnNext->setText("&Next");
+    m_btnNext->setText(tr("&Next"));
     m_btnNext->setEnabled(false);
     m_btnMore->setEnabled(false);
     m_btnNext->hide();
     m_btnMore->hide();
-    m_btnClear->setText("&Ok");
+    m_btnClear->setText(tr("&Ok"));
     showExtension(false); // We are opening the window, so default to not showing this
   }
   else
   {
     m_nUnreadNum++;
     unread = true; // It is unread
-    m_btnClear->setText("&Clear All");
-    QString nextStr = QString("&Next (%1)").arg(m_nUnreadNum);
+    m_btnClear->setText(tr("&Clear All"));
+    QString nextStr = QString(tr("&Next (%1)")).arg(m_nUnreadNum);
     m_btnNext->setText(nextStr);
     if (!m_btnNext->isEnabled())
     {
@@ -1325,25 +1446,28 @@ void CLicqMessageBox::slot_listChanged(QListViewItem *i)
 {
   // Change the icon, message and caption
   CLicqMessageBoxItem *item = dynamic_cast<CLicqMessageBoxItem *>(i);
-  m_lblIcon->setPixmap(item->getFullIcon());
-  m_lblMessage->setText(item->getMessage());
-  updateCaption(item);
-
-  // Mark it as read
-  if (item->isUnread())
+  if (item != NULL)
   {
-    m_nUnreadNum--;
-    item->setUnread(false);
+    m_lblIcon->setPixmap(item->getFullIcon());
+    m_lblMessage->setText(item->getMessage());
+    updateCaption(item);
+
+    // Mark it as read
+    if (item->isUnread())
+    {
+      m_nUnreadNum--;
+      item->setUnread(false);
+    }
   }
 
   // Update the next button
   QString nextStr;
   if (m_nUnreadNum > 0)
-    nextStr = QString("&Next (%1)").arg(m_nUnreadNum);
+    nextStr = QString(tr("&Next (%1)")).arg(m_nUnreadNum);
   else
   {
     // No more unread messages
-    nextStr = QString("&Next");
+    nextStr = QString(tr("&Next"));
     m_btnNext->setEnabled(false);
     m_nUnreadNum = 0;
   }
@@ -1364,21 +1488,21 @@ void CLicqMessageBox::updateCaption(CLicqMessageBoxItem *item)
   switch (item->getType())
   {
     case QMessageBox::Information:
-      strCaption = "Licq Information";
+      strCaption = tr("Licq Information");
       break;
 
     case QMessageBox::Warning:
-      strCaption = "Licq Warning";
+      strCaption = tr("Licq Warning");
       break;
 
     case QMessageBox::Critical:
-      strCaption = "Licq Critical";
+      strCaption = tr("Licq Critical");
       break;
 
     case QMessageBox::NoIcon:
     case QMessageBox::Question:
     default:
-      strCaption = "Licq";
+      strCaption = tr("Licq");
       break;
   }
   setCaption(strCaption);
