@@ -1,21 +1,21 @@
-/* This file is part of the Licq project
-   Copyright (C) 2005 Kevin Krammer <kevin.krammer@gmx.at>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
-*/
+/*
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 2005 Kevin Krammer <kevin.krammer@gmx.at>
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -41,6 +41,7 @@
 // local includes
 #include "licqkimiface.h"
 #include "mainwin.h"
+#include "gui-strings.h"
 
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -209,9 +210,7 @@ QString LicqKIMIface::presenceString(const QString& uid)
 /*        kdDebug() << pUser->GetAlias()
                     << ": Licq ID=(" << pUser->PPID() << ", " << id << ")"
                     << "KABC ID=" << kabcID << endl;*/
-        QTextCodec* codec = UserCodec::codecForICQUser(pUser);
-        QCString rawStatus = pUser->StatusStr();
-        status = codec->toUnicode(rawStatus);
+        status = Strings::getStatus(pUser);
         FOR_EACH_PROTO_USER_BREAK
     }
     FOR_EACH_PROTO_USER_END
