@@ -1,3 +1,22 @@
+/*
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 1999-2006 Licq developers
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
 #ifndef MESSAGEBOX_H
 #define MESSAGEBOX_H
 
@@ -8,7 +27,6 @@
 
 class CUserEvent;
 class MsgView;
-class CMsgViewTips;
 
 //=====UserViewItem================================================================================
 class MsgViewItem : public QListViewItem
@@ -24,11 +42,10 @@ public:
 
 protected:
   virtual void paintCell(QPainter *, const QColorGroup &, int column, int width, int align);
-  virtual void paintFocus(QPainter *, const QColorGroup &cg, const QRect &r) {}
+  virtual void paintFocus(QPainter *, const QColorGroup &, const QRect &) {}
 
   void SetEventLine();
 
-friend class CMsgViewTips;
 friend class MsgView;
 };
 
@@ -46,7 +63,6 @@ signals:
   void sizeChange(int, int, int);
 
 protected:
-  CMsgViewTips *tips;
 
   virtual void resizeEvent(QResizeEvent *e);
   virtual void maybeTip(const QPoint&);
