@@ -1,20 +1,22 @@
 // -*- c-basic-offset: 2 -*-
 /*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-*/
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 1999-2006 Licq developers
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 #include <qdir.h>
 #include <qframe.h>
@@ -35,6 +37,7 @@
 #include "mainwin.h"
 #include "skin.h"
 #include "skinbrowser.h"
+#include "gui-strings.h"
 #include "emoticon.h"
 
 enum {
@@ -103,7 +106,7 @@ SkinBrowserDlg::SkinBrowserDlg(CMainWindow *_mainwin, QWidget *parent)
 	QWhatsThis::add(cmbExtIcon, tr("Use this combo box to select one of the available extended icon sets"));
 	lblExtIcon->setBuddy(cmbExtIcon);
 
-	QLabel *lblEmoticons = new QLabel(tr("E&moticons"), boxSkin);
+	QLabel *lblEmoticons = new QLabel(tr("E&moticons:"), boxSkin);
 	cmbEmoticon = new QComboBox(boxSkin);
 	QWhatsThis::add(cmbEmoticon, tr("Use this combo box to select one of "
 	                                "the available emoticon icon sets"));
@@ -537,7 +540,7 @@ void SkinBrowserDlg::slot_loadEmoticons(const QString &emoticon)
  *	preview areas to be updated so that it looks nice with structured
  *	backgrounds.
  */
-void SkinBrowserDlg::resizeEvent(QResizeEvent *e)
+void SkinBrowserDlg::resizeEvent(QResizeEvent* /* e */)
 {
 	lblPaintSkin->update();
 	lblPaintIcon->update();
@@ -564,7 +567,7 @@ void SkinBrowserPreviewArea::setPixmapList(QValueList<QPixmap> *_lstPm)
 	this->update();
 }
 
-void SkinBrowserPreviewArea::paintEvent(QPaintEvent *e)
+void SkinBrowserPreviewArea::paintEvent(QPaintEvent* /* e */)
 {
 	QPainter p(this);
 	unsigned short int X = 0;
@@ -606,18 +609,12 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 	if (skin->frame.pixmap != NULL)
 	{
 		p = (QImage(skin->frame.pixmap).smoothScale(w.width(), w.height()));
-#if QT_VERSION < 300
-		w.setBackgroundPixmap(p);
-#else
 		w.setPaletteBackgroundPixmap(p);
-#endif
 	}
 	else
 	{
 		setBackgroundMode(PaletteBackground);
-#if QT_VERSION >= 300
 		unsetPalette();
-#endif
 	}
 
 	// Group Combo Box
@@ -625,7 +622,7 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 	cmbUserGroups->setNamedBgColor(skin->cmbGroups.color.bg);
 	cmbUserGroups->setNamedFgColor(skin->cmbGroups.color.fg);
 	cmbUserGroups->setGeometry(skin->borderToRect(&skin->cmbGroups, &w));
-	cmbUserGroups->insertItem("All Users");
+	cmbUserGroups->insertItem(Strings::getSystemGroupName(GROUP_ALL_USERS));
 
 	// The Menu Button
 	if (!skin->frame.hasMenuBar)
@@ -663,10 +660,6 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 	lblMsg->setNamedBgColor(skin->lblMsg.color.bg);
 	if (skin->lblMsg.pixmap != NULL)
 	{
-#if QT_VERSION < 300
-		lblMsg->setBackgroundPixmap(QPixmap(skin->lblMsg.pixmap));
-	}
-#else
 		lblMsg->setBackgroundOrigin(w.ParentOrigin);
 		lblMsg->setPaletteBackgroundPixmap(p);
 		lblMsg->setPixmap(QPixmap(skin->lblMsg.pixmap));
@@ -676,9 +669,9 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 		lblMsg->setBackgroundOrigin(w.ParentOrigin);
 		lblMsg->setPaletteBackgroundPixmap(p);
 	}
-#endif
+
 	lblMsg->setGeometry(skin->borderToRect(&skin->lblMsg, &w));
-	lblMsg->setText("New Users");
+	lblMsg->setText(Strings::getSystemGroupName(GROUP_NEW_USERS));
 
   // Status Label
 	lblStatus = new CELabel(skin->lblStatus.transparent, NULL, &w);
@@ -688,10 +681,6 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 	lblStatus->setNamedBgColor(skin->lblStatus.color.bg);
 	if (skin->lblStatus.pixmap != NULL)
 	{
-#if QT_VERSION < 300
-		lblStatus->setBackgroundPixmap(p);
-	}
-#else
 		lblStatus->setBackgroundOrigin(w.ParentOrigin);
 		lblStatus->setPaletteBackgroundPixmap(p);
 		lblStatus->setPixmap(QPixmap(skin->lblStatus.pixmap));
@@ -701,9 +690,9 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 		lblStatus->setBackgroundOrigin(w.ParentOrigin);
 		lblStatus->setPaletteBackgroundPixmap(p);
 	}
-#endif
+
 	lblStatus->setGeometry(skin->borderToRect(&skin->lblStatus, &w));
-	lblStatus->setText("Online");
+	lblStatus->setText(Strings::getStatus(ICQ_STATUS_ONLINE, false));
 	lblStatus->setPrependPixmap(CMainWindow::iconForStatus(ICQ_STATUS_ONLINE));
 
 	// Userview
@@ -717,19 +706,16 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 	char * c_newuser    = mainwin->skin->colors.newuser;
 	char * c_background = mainwin->skin->colors.background;
 	char * c_gridlines  = mainwin->skin->colors.gridlines;
+  char* c_groupBack     = mainwin->skin->colors.groupBack;
 
   userView.QListView::setPalette(skin->palette(this));
-	userView.setColors(skin->colors.online, skin->colors.away,
-											skin->colors.offline, skin->colors.newuser,
-											skin->colors.background, skin->colors.gridlines);
+  userView.setColors(skin->colors.online, skin->colors.away,
+      skin->colors.offline, skin->colors.newuser,
+      skin->colors.background, skin->colors.gridlines, skin->colors.groupBack);
 	if (skin->frame.transparent)
 	{
-#if QT_VERSION < 300
-	userView.setBackgroundPixmap(p);
-#else
 	userView.setBackgroundOrigin(w.ParentOrigin);
 	userView.setPaletteBackgroundPixmap(p);
-#endif
 	}
 	userView.show();
 
@@ -738,7 +724,7 @@ QPixmap SkinBrowserDlg::renderSkin(const QString &skinName)
 	ret.convertFromImage(QImage(tmp.convertToImage().smoothScale(75, MAX_HEIGHT_SKIN)));
 
 	// Reset origin colors
-	userView.setColors(c_online, c_away, c_offline, c_newuser, c_background, c_gridlines);
+  userView.setColors(c_online, c_away, c_offline, c_newuser, c_background, c_gridlines, c_groupBack);
 
 	delete btnSystem;
 	delete lblMsg;
