@@ -1,20 +1,23 @@
 // -*- c-basic-offset: 2 -*-
 /*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 1999-2006 Licq developers
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-*/
 #include <ctype.h>
 #include <stdio.h>
 
@@ -32,12 +35,14 @@
 #include <qstyle.h>
 #include <qimage.h>
 #include <qmime.h>
+#include <qtimer.h>
 
 #include "userbox.moc"
 #include "skin.h"
 #include "mainwin.h"
 #include "userbox.h"
 #include "gui-defines.h"
+#include "gui-strings.h"
 #include "mainwin.h"
 #include "usereventdlg.h"
 #include "usercodec.h"
@@ -60,7 +65,8 @@ QColor  *CUserViewItem::s_cOnline = NULL,
         *CUserViewItem::s_cOffline = NULL,
         *CUserViewItem::s_cNew = NULL,
         *CUserViewItem::s_cBack = NULL,
-        *CUserViewItem::s_cGridLines = NULL;
+        *CUserViewItem::s_cGridLines = NULL,
+        *CUserViewItem::s_cGroupBack = 0;
 
 //-----CUserViewItem::constructor-----------------------------------------------
 CUserViewItem::CUserViewItem(ICQUser *_cUser, QListView *parent)
@@ -68,9 +74,8 @@ CUserViewItem::CUserViewItem(ICQUser *_cUser, QListView *parent)
 {
   if(listView()->parent() == NULL)
     listView()->setCaption(CUserView::tr("%1 Floaty (%2)")
-                           .arg(_cUser->GetAlias()).arg(_cUser->IdString()));
+                           .arg(QString::fromUtf8(_cUser->GetAlias())).arg(_cUser->IdString()));
 
-  m_nUin = _cUser->Uin();
   if (_cUser->IdString())
   {
     char *szRealId = 0;
@@ -102,7 +107,6 @@ CUserViewItem::CUserViewItem (ICQUser *_cUser, CUserViewItem* item)
     m_sGroupName()
 {
   m_nGroupId = (unsigned short)(-1);
-  m_nUin = _cUser->Uin();
   if (_cUser->IdString())
   {
     char *szRealId = 0;
@@ -120,7 +124,6 @@ CUserViewItem::CUserViewItem (ICQUser *_cUser, CUserViewItem* item)
   m_bBirthday = false;
   m_bPhone = false;
   m_bCellular = false;
-  m_bGPGKey = false;
   m_nOnlCount = 0;
   m_nEvents = 0;
   m_nStatus = ICQ_STATUS_OFFLINE;
@@ -135,12 +138,11 @@ CUserViewItem::CUserViewItem(unsigned short Id, const char* name, QListView* lv)
     m_nGroupId(Id),
     m_sGroupName(name)
 {
-  m_nUin = 0;
   m_szId = 0;
   m_szAlias = 0;
   m_nPPID =0;
   m_pIcon = NULL;
-  m_cBack = s_cBack;
+  m_cBack = s_cGroupBack;
   m_cFore = s_cGridLines;
   m_bItalic = m_bStrike = false;
   m_nWeight = QFont::Bold;
@@ -152,6 +154,8 @@ CUserViewItem::CUserViewItem(unsigned short Id, const char* name, QListView* lv)
   m_nOnlCount = 0;
   m_nEvents = 0;
   m_nStatus = 0;
+  m_bGPGKey = false;
+  m_bNotInList = true;
   m_pUserIcon = 0;
   // Other users group is sorted at the end
   if (m_nGroupId)
@@ -174,12 +178,13 @@ CUserViewItem::CUserViewItem(BarType barType, QListView *parent)
     m_sGroupName()
 {
   m_nGroupId = (unsigned short)(-1);
-  m_nUin = 0;
   m_szId = 0;
   m_nPPID = 0;
   m_nOnlCount = 0;
   m_nEvents = 0;
   m_nStatus = 0;
+  m_bGPGKey = false;
+  m_bNotInList = true;
   m_pIcon = NULL;
   m_cBack = s_cBack;
   m_cFore = s_cOnline;
@@ -364,7 +369,7 @@ void CUserViewItem::setGraphics(ICQUser *u)
      if (m_pUserIcon == 0)
      {
        QString strPath = QString(BASE_DIR) + QString("/") + QString(USER_DIR) +
-	 QString("/") + QString(u->IdString()) + QString(".pic");
+          QString("/") + QString(u->IdString()) + QString(".pic");
        QImage tmpImg(strPath);
        if (!tmpImg.isNull())
        {
@@ -854,8 +859,6 @@ void CUserView::timerEvent(QTimerEvent* e)
     }
 
     if(--carCounter == 0) {
-      carUin = 0;
-
       if (carId)
       {
         free(carId);
@@ -898,8 +901,6 @@ void CUserView::timerEvent(QTimerEvent* e)
     }
 
     if(!found || (--onlCounter == 0)) {
-      onlUin = 0;
-
       if (onlId)
       {
         free(onlId);
@@ -1008,10 +1009,13 @@ CUserView::CUserView(QPopupMenu *m, QWidget *parent, const char *name)
     setWFlags(getWFlags() | WDestructiveClose);
     setShowHeader(false);
     setFrameStyle(33);
+
     XClassHint classhint;
-    classhint.res_name = "licq";
+    classhint.res_name = strdup("licq");
     classhint.res_class = szClass;
     XSetClassHint(x11Display(), winId(), &classhint);
+    free(classhint.res_name);
+
     XWMHints *hints = XGetWMHints(x11Display(), winId());
     hints->window_group = winId();
     hints->flags = WindowGroupHint;
@@ -1022,6 +1026,11 @@ CUserView::CUserView(QPopupMenu *m, QWidget *parent, const char *name)
   }
 
   carId = onlId = 0;
+
+  // Redraw once a minute in case there are cells showing timestamps
+  tmrRefresh = new QTimer(this);
+  connect(tmrRefresh, SIGNAL(timeout()), this, SLOT(updateItems()));
+  tmrRefresh->start(60000);
 }
 
 // -----------------------------------------------------------------------------
@@ -1029,6 +1038,7 @@ CUserView::CUserView(QPopupMenu *m, QWidget *parent, const char *name)
 
 CUserView::~CUserView()
 {
+  tmrRefresh->stop();
   barOnline = barOffline = barNotInList = NULL;
   if (parent() == NULL)
   {
@@ -1076,7 +1086,7 @@ void CUserView::clear()
 
 //-----CUserView::setColors-----------------------------------------------------
 void CUserView::setColors(char *_sOnline, char *_sAway, char *_sOffline,
-                          char *_sNew, char *_sBack, char *_sGridLines)
+                          char *_sNew, char *_sBack, char *_sGridLines, char *_sGroupBack)
 {
    if (CUserViewItem::s_cOnline == NULL) CUserViewItem::s_cOnline = new QColor;
    if (CUserViewItem::s_cAway == NULL) CUserViewItem::s_cAway = new QColor;
@@ -1084,12 +1094,14 @@ void CUserView::setColors(char *_sOnline, char *_sAway, char *_sOffline,
    if (CUserViewItem::s_cNew == NULL) CUserViewItem::s_cNew = new QColor;
    if (CUserViewItem::s_cBack == NULL) CUserViewItem::s_cBack = new QColor;
    if (CUserViewItem::s_cGridLines == NULL) CUserViewItem::s_cGridLines = new QColor;
+  if (CUserViewItem::s_cGroupBack == 0) CUserViewItem::s_cGroupBack = new QColor;
 
    CUserViewItem::s_cOnline->setNamedColor(_sOnline);
    CUserViewItem::s_cAway->setNamedColor(_sAway);
    CUserViewItem::s_cOffline->setNamedColor(_sOffline);
    CUserViewItem::s_cNew->setNamedColor(_sNew);
    CUserViewItem::s_cGridLines->setNamedColor(_sGridLines);
+  CUserViewItem::s_cGroupBack->setNamedColor(_sGroupBack);
    if (gMainWindow->m_bSystemBackground)
    {
      *CUserViewItem::s_cBack =
@@ -1097,10 +1109,7 @@ void CUserView::setColors(char *_sOnline, char *_sAway, char *_sOffline,
    }
    else
    {
-     if (_sBack != NULL)
-       CUserViewItem::s_cBack->setNamedColor(_sBack);
-     else
-       CUserViewItem::s_cBack->setNamedColor("grey76");
+    CUserViewItem::s_cBack->setNamedColor(_sBack);
 
      QPalette pal(QListView::palette());
      pal.setColor(QColorGroup::Base, *CUserViewItem::s_cBack);
@@ -1115,13 +1124,6 @@ void CUserView::setShowHeader(bool isHeader)
 }
 
 
-unsigned long CUserView::MainWindowSelectedItemUin()
-{
-   CUserViewItem *i = (CUserViewItem *)currentItem();
-   if (i == NULL) return (0);
-   return i->ItemUin();
-}
-
 bool CUserView::MainWindowSelectedItemUser(char *&_szId, unsigned long &_nPPID)
 {
   CUserViewItem *i = (CUserViewItem *)currentItem();
@@ -1514,17 +1516,6 @@ void CUserView::resizeEvent(QResizeEvent *e)
   }
 }
 
-void CUserView::AnimationAutoResponseCheck(unsigned long uin)
-{
-  if(carTimerId == 0) {
-    // no animation yet running, so start the timer
-    carTimerId = startTimer(FLASH_TIME);
-    carCounter = 5*1000/FLASH_TIME; // run about 5 seconds
-    carUin = uin;
-  }
-  // well, maybe we should move the animation to the other user
-}
-
 void CUserView::AnimationAutoResponseCheck(const char *szId, unsigned long nPPID)
 {
   if(carTimerId == 0) {
@@ -1537,27 +1528,6 @@ void CUserView::AnimationAutoResponseCheck(const char *szId, unsigned long nPPID
   // well, maybe we should move the animation to the other user
 }
 
-void CUserView::AnimationOnline(unsigned long uin)
-{
-  if(onlTimerId == 0) {
-    onlTimerId = startTimer(FLASH_TIME);
-    // run about 5 seconds, make sure that that the
-    // actual "flashing" starts with a delay, because of the
-    // logon case.
-    onlCounter = ((5*1000/FLASH_TIME)+1)&(-2);
-    onlUin = uin;
-  }
-  else if((onlCounter & 1) == 0 && onlUin != uin)
-  {
-    // whoops, another user went online
-    // we just block here the blinking for the
-    // rest of the time
-    onlUin = 0;
-    // no need for a redraw, as the user is already shown
-    // correctly.
-  }
-}
-
 void CUserView::AnimationOnline(const char *szId, unsigned long nPPID)
 {
   if(onlTimerId == 0) {
@@ -1618,6 +1588,22 @@ void CUserView::UpdateFloaties()
   }
 }
 
+// -----------------------------------------------------------------------------
+
+void CUserView::updateItems()
+{
+  for (QListViewItemIterator it(firstChild()); it.current() != 0; ++it)
+  {
+    CUserViewItem* item = static_cast<CUserViewItem*>(it.current());
+
+    ICQUser *u = gUserManager.FetchUser(item->ItemId(), item->ItemPPID(), LOCK_R);
+    if (u == 0)
+      continue;
+    item->setGraphics(u);
+    gUserManager.DropUser(u);
+  }
+  triggerUpdate();
+}
 
 // -----------------------------------------------------------------------------
 
@@ -1672,111 +1658,117 @@ void CUserView::itemCollapsed(QListViewItem* i)
 void CUserView::maybeTip(const QPoint& c)
 {
   CUserViewItem* item = static_cast<CUserViewItem*>(itemAt(c));
-  if (item && item->m_szId)
+  if (item == NULL || item->m_szId == NULL)
+    return;
+
+  QString s = "<nobr>";
+  s += Strings::getStatus(item->m_nStatus, item->m_bStatusInvisible);
+
+  QRect r(itemRect(item));
+
+  ICQUser* u = gUserManager.FetchUser(item->m_szId, item->m_nPPID, LOCK_R);
+  if (u != NULL)
   {
-    QRect r(itemRect(item));
-    ICQUser *u = gUserManager.FetchUser(item->m_szId, item->m_nPPID, LOCK_R);
-    QTextCodec * codec = UserCodec::codecForICQUser(u);
-    QString strFileName = "";
-    if (u && u->GetPicturePresent())
+    if (u->GetPicturePresent() && gMainWindow->m_bPopPicture)
     {
-      const QString file = QString("%1/%2/%3.pic").arg(BASE_DIR).arg(USER_DIR).arg(u->IdString());
+      const QString file =
+          QString("%1/%2/%3.pic").arg(BASE_DIR).arg(USER_DIR).arg(u->IdString());
       const QImage picture = QImage(file);
       if (!picture.isNull())
       {
         QMimeSourceFactory::defaultFactory()->setImage(file, picture);
-        strFileName = QString("<center><img src=\"%1\"></center>").arg(file);
+        s = QString("<center><img src=\"%1\"></center>").arg(file) + s;
       }
     }
 
-    QString s = strFileName + QString("<nobr>") + QString(ICQUser::StatusToStatusStr(item->m_nStatus, item->m_bStatusInvisible))
-      + QString("</nobr>");
-    
+    QTextCodec* codec = UserCodec::codecForICQUser(u);
+
     if (*u->GetAlias() && gMainWindow->m_bPopAlias)
-      s += tr("<br><nobr>") + QString::fromUtf8(u->GetAlias()) + tr("</nobr>");
+      s += "<br>" + QString::fromUtf8(u->GetAlias());
 
     if ((*u->GetFirstName() || *u->GetLastName()) && gMainWindow->m_bPopName)
     {
-      s += tr("<br><nobr>");
+      s += "<br>";
       if (*u->GetFirstName())
         s += codec->toUnicode(u->GetFirstName());
       if (*u->GetFirstName() && *u->GetLastName())
         s += " ";
       if (*u->GetLastName())
         s += codec->toUnicode(u->GetLastName());
-      s += tr("</nobr>");
     }
 
     if (item->m_nStatusFull & ICQ_STATUS_FxBIRTHDAY)
-      s += tr("<br><b>Birthday&nbsp;Today!</b>");
-    
+      s += "<br><b>" + tr("Birthday Today!") + "</b>";
+
     if (item->m_nStatus != ICQ_STATUS_OFFLINE)
     {
       if (item->m_bStatusTyping)
-        s += tr("<br>Typing&nbsp;a&nbsp;message");
+        s += "<br>" + tr("Typing a message");
       if (item->m_nPhoneFollowMeStatus == ICQ_PLUGIN_STATUSxACTIVE)
-        s += tr("<br>Phone&nbsp;&quot;Follow&nbsp;Me&quot;:&nbsp;Available");
+        s += "<br>" + tr("Phone &quot;Follow Me&quot;: Available");
       else if (item->m_nPhoneFollowMeStatus == ICQ_PLUGIN_STATUSxBUSY)
-        s += tr("<br>Phone&nbsp;&quot;Follow&nbsp;Me&quot;:&nbsp;Busy");
+        s += "<br>" + tr("Phone &quot;Follow Me&quot;: Busy");
 
       if (item->m_nICQphoneStatus == ICQ_PLUGIN_STATUSxACTIVE)
-        s += tr("<br>ICQphone:&nbsp;Available");
+        s += "<br>" + tr("ICQphone: Available");
       else if (item->m_nICQphoneStatus == ICQ_PLUGIN_STATUSxBUSY)
-        s += tr("<br>ICQphone:&nbsp;Busy");
+        s += "<br>" + tr("ICQphone: Busy");
 
       if (item->m_nSharedFilesStatus == ICQ_PLUGIN_STATUSxACTIVE)
-        s += tr("<br>File&nbsp;Server:&nbsp;Enabled");
+        s += "<br>" + tr("File Server: Enabled");
     }
 
     if (item->m_bSecure)
-      s += tr("<br>Secure&nbsp;connection");
+      s += "<br>" + tr("Secure connection");
 
     if (item->m_bCustomAR)
-      s += tr("<br>Custom&nbsp;Auto&nbsp;Response");
+      s += "<br>" + tr("Custom Auto Response");
 
-    if (u != NULL)
-    {
-      if (!u->StatusOffline() && u->ClientInfo() && *u->ClientInfo())
-      s += tr("<br><nobr>") + codec->toUnicode(u->ClientInfo()) + tr("</nobr>");
-      
-      if (u->AutoResponse() && *u->AutoResponse() &&
-          item->m_nStatus != ICQ_STATUS_OFFLINE &&
-          item->m_nStatus != ICQ_STATUS_ONLINE)
-        s += tr("<br><u>Auto Response:</u>") + codec->toUnicode(u->AutoResponse());
-      gUserManager.DropUser(u);
-    }
+    if (u->GetAwaitingAuth())
+      s += "<br>" + tr("Awaiting authorization");
+
+    if (!u->StatusOffline() && u->ClientInfo() && *u->ClientInfo())
+      s += "<br>" + codec->toUnicode(u->ClientInfo());
+
+    if (u->AutoResponse() && *u->AutoResponse() &&
+        item->m_nStatus != ICQ_STATUS_OFFLINE &&
+        item->m_nStatus != ICQ_STATUS_ONLINE)
+      s += "<br><u>" + tr("Auto Response:") + "</u>" + codec->toUnicode(u->AutoResponse());
 
     if (*u->GetEmailPrimary() && gMainWindow->m_bPopEmail)
-      s += tr("<br><nobr>E: ") + codec->toUnicode(u->GetEmailPrimary()) + tr("</nobr>");
+      s += "<br>" + tr("E: ") + codec->toUnicode(u->GetEmailPrimary());
 
     if (item->m_bPhone && gMainWindow->m_bPopPhone)
-      s += tr("<br><nobr>P: ") + codec->toUnicode(u->GetPhoneNumber()) + tr("</nobr>");
+      s += "<br>" + tr("P: ") + codec->toUnicode(u->GetPhoneNumber());
 
     if (item->m_bCellular && gMainWindow->m_bPopCellular)
-      s += tr("<br><nobr>C: ") + codec->toUnicode(u->GetCellularNumber()) + tr("</nobr>");
+      s += "<br>" + tr("C: ") + codec->toUnicode(u->GetCellularNumber());
 
-    if ((u->GetFaxNumber()[0]!='\0') && gMainWindow->m_bPopEmail)
-      s += tr("<br><nobr>F: ") + codec->toUnicode(u->GetFaxNumber()) + tr("</nobr>");
+    if ((u->GetFaxNumber()[0] != '\0') && gMainWindow->m_bPopEmail)
+      s += "<br>" + tr("F: ") + codec->toUnicode(u->GetFaxNumber());
 
-    if ((u->Ip() || u->IntIp()) && gMainWindow->m_bPopIP) {
+    if ((u->Ip() || u->IntIp()) && gMainWindow->m_bPopIP)
+    {
       char buf_ip[32];
       char buf_int_ip[32];
       ip_ntoa(u->Ip(), buf_ip);
       ip_ntoa(u->IntIp(), buf_int_ip);
       if (u->Ip() != u->IntIp() && u->IntIp() != 0)
-        s += tr("<br><nobr>Ip: ") + buf_ip + "/" + buf_int_ip + tr("</nobr>");
+        s += "<br>" + tr("Ip: ") + buf_ip + "/" + buf_int_ip;
       else
-        s += tr("<br><nobr>Ip: ") + buf_ip + tr("</nobr>");
+        s += "<br>" + tr("Ip: ") + buf_ip;
     }
 
-    if ((u->LastOnline()>0) && gMainWindow->m_bPopLastOnline) {
+    if ((u->LastOnline() > 0) && gMainWindow->m_bPopLastOnline)
+    {
       QDateTime t;
       t.setTime_t(u->LastOnline());
       QString ds = t.toString();
-      s += tr("<br><nobr>O: ") +  ds + tr("</nobr>");
+      s += "<br>" + tr("O: ") +  ds;
     }
 
-    if ((!u->StatusOffline()) && gMainWindow->m_bPopOnlineSince) {
+    if ((!u->StatusOffline()) && gMainWindow->m_bPopOnlineSince)
+    {
       time_t nLoggedIn = time(0) - u->OnlineSince();
       unsigned long nWeek, nDay, nHour, nMinute;
       nWeek = nLoggedIn / 604800;
@@ -1813,7 +1805,7 @@ void CUserView::maybeTip(const QPoint& c)
       if (!nWeek && !nDay && !nHour && !nMinute)
         ds += tr("0 minutes");
 
-      s += tr("<br><nobr>Logged In: ") + ds + tr("</nobr>");
+      s += "<br>" + tr("Logged In: ") + ds;
     }
 
     if (gMainWindow->m_bPopIdleTime)
@@ -1824,23 +1816,33 @@ void CUserView::maybeTip(const QPoint& c)
         szTemp = u->usprintf("%I");
         QString temp(szTemp);
         free(szTemp);
-        s += tr("<br><nobr>Idle: ") + temp + tr("</nobr>");
-        tip (r, s);
+        s += "<br>" + tr("Idle: ") + temp;
       }
     }
-   
+
+    if (gMainWindow->m_bPopLocalTime)
+    {
+      char *szTemp;
+      szTemp = u->usprintf("%F");
+      QString temp(szTemp);
+      free(szTemp);
+      s += "<br>" + tr("Local time: ") + temp;
+    }
+
     if (gMainWindow->m_bPopID)
     {
       char *szTemp;
       szTemp = u->usprintf("%u");
       QString temp(szTemp);
       free(szTemp);
-      s += tr("<br><nobr>ID: ") + temp + tr("</nobr>");
-      tip (r, s);
+      s += "<br>" + tr("ID: ") + temp;
     }
 
-    tip(r, s);
+    gUserManager.DropUser(u);
   }
+
+  s += "</nobr>";
+  tip(r, s);
 }
 
 void CUserView::setSorting( int column, bool ascending)
