@@ -1,20 +1,22 @@
 // -*- c-basic-offset: 2 -*-
 /*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-*/
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 2000-2006 Licq developers
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 // written by Graham Roff <graham@licq.org>
 // contributions by Dirk A. Mueller <dirk@licq.org>
@@ -79,6 +81,7 @@
 #include "sigman.h"
 #include "mledit.h"
 #include "mlview.h"
+#include "gui-strings.h"
 
 #include "xpm/phonebookPhone.xpm"
 #include "xpm/phonebookCellular.xpm"
@@ -116,7 +119,7 @@ UserInfoDlg::UserInfoDlg(CICQDaemon *s, CSignalManager *theSigMan, CMainWindow *
 
   QBoxLayout *lay = new QVBoxLayout(this, 8);
 
-  tabs = new QTabWidget(this);
+  tabs = new CETabWidget(this);
   lay->addWidget(tabs, 2);
 
   tabs->addTab(tabList[GeneralInfo].tab, tabList[GeneralInfo].label);
@@ -231,6 +234,7 @@ UserInfoDlg::~UserInfoDlg()
     delete m_PhoneBook;
 
   emit finished(m_szId, m_nPPID);
+  free(m_szId);
 
   ICQUser::ClearHistory(m_lHistoryList);
 }
@@ -305,8 +309,8 @@ void UserInfoDlg::CreateGeneralInfo()
   nfoStatus = new CInfoField(p, true);
   lay->addWidget(nfoStatus, CR, 1);
   lay->addWidget(new QLabel(tr("Timezone:"), p), CR, 3);
-  nfoTime = new CInfoField(p, true);
-  lay->addWidget(nfoTime, CR, 4);
+  tznZone = new CTimeZoneField(p);
+  lay->addWidget(tznZone, CR, 4);
 
   lay->addWidget(new QLabel(tr("Name:"), p), ++CR, 0);
   nfoFirstName = new CInfoField(p, false);
@@ -411,17 +415,13 @@ void UserInfoDlg::SetGeneralInfo(ICQUser *u)
     ip.append(QString(":%1").arg(u->PortStr(buf)));
   }
   nfoIp->setData(ip);
-  if (u->GetTimezone() == TIMEZONE_UNKNOWN)
-    nfoTime->setText(tr("Unknown"));
-  else
-  {
-    nfoTime->setText(tr("GMT%1%1%1")
-       .arg(u->GetTimezone() > 0 ? "-" : "+")
-       .arg(abs(u->GetTimezone() / 2)).arg(u->GetTimezone() % 2 ? "30" : "00") );
-  }
-  nfoStatus->setData(u->StatusStr());
+  tznZone->setData(u->GetTimezone());
+  nfoStatus->setData(Strings::getStatus(u));
   if (m_bOwner)
   {
+    // Owner timezone is not editable, it is taken from system timezone instead
+    tznZone->setEnabled(false);
+
     const SCountry *c = GetCountryByCode(u->GetCountryCode());
     if (c == NULL)
       cmbCountry->setCurrentItem(0);
@@ -488,6 +488,7 @@ void UserInfoDlg::SaveGeneralInfo()
     unsigned short i = cmbCountry->currentItem();
     u->SetCountryCode(GetCountryByIndex(i)->nCode);
   }
+  u->SetTimezone(tznZone->data());
 
   u->SetEnableSave(true);
   u->SaveGeneralInfo();
@@ -1177,13 +1178,10 @@ void UserInfoDlg::CreateAbout()
   p->setSpacing(8);
 
   lblAbout = new QLabel(tr("About:"), p);
-  mlvAbout = new CHistoryWidget(p, "About");//EditWrap(true, p);
+  mlvAbout = new MLView(p, "About");//EditWrap(true, p);
   mlvAbout->setReadOnly(!m_bOwner);
   mlvAbout->setTextFormat(RichText);
-#if QT_VERSION >= 300
   connect(mlvAbout, SIGNAL(viewurl(QWidget*, QString)), mainwin, SLOT(slot_viewurl(QWidget *, QString)));
-#endif
-
 }
 
 void UserInfoDlg::SetAbout(ICQUser *u)
@@ -1726,11 +1724,10 @@ void UserInfoDlg::CreateHistory()
   chkHistoryReverse->setFixedSize(chkHistoryReverse->sizeHint());
   l->addWidget(chkHistoryReverse);
 
-  mlvHistory = new CMessageViewWidget(m_szId, m_nPPID, mainwin, p, "history");
-  mlvHistory->m_nMsgStyle = 4; /* STYLE_HISTORY */
-#if QT_VERSION >= 300
+  mlvHistory = new CMessageViewWidget(m_szId, m_nPPID, mainwin, p, "history", true);
+
   connect(mlvHistory, SIGNAL(viewurl(QWidget*, QString)), mainwin, SLOT(slot_viewurl(QWidget *, QString)));
-#endif
+
   lay->addWidget(mlvHistory, 1);
 
   l = new QHBoxLayout(lay);
@@ -1897,6 +1894,7 @@ void UserInfoDlg::SetupHistory()
       mlvHistory->setText(tr("Sorry, history is disabled for this person."));
 
     btnMain2->setEnabled(false);
+    gUserManager.DropUser(u);
   }
   else
   {
@@ -1910,11 +1908,11 @@ void UserInfoDlg::SetupHistory()
       m_iHistorySIter--;
     }
     m_nHistoryIndex = m_lHistoryList.size();
+    gUserManager.DropUser(u);
     ShowHistory();
 
     btnMain2->setEnabled((m_nHistoryIndex - m_nHistoryShowing) != 0);
   }
-  gUserManager.DropUser(u);
 
   btnMain3->setEnabled(false);
 }
@@ -2028,7 +2026,18 @@ void UserInfoDlg::ShowHistory()
   barFiltering->setTotalSteps(NUM_MSG_PER_HISTORY);
   char* ftxt = qstrdup(codec->fromUnicode(lneFilter->text()));
   int flen = strlen(ftxt);
-  
+
+  QString ownerName;
+  ICQOwner *o = gUserManager.FetchOwner(m_nPPID, LOCK_R);
+  if (o != NULL)
+  {
+    // Don't use this codec to decode our conversation with the contact
+    // since we're using the contact's encoding, not ours.
+    QTextCodec *ownerCodec = UserCodec::codecForICQUser(o);
+    ownerName = ownerCodec->toUnicode(o->GetAlias());
+    gUserManager.DropOwner(m_nPPID);
+  }
+
   mlvHistory->clear();
   while (m_nHistoryShowing < (NUM_MSG_PER_HISTORY))
   {
@@ -2041,33 +2050,15 @@ void UserInfoDlg::ShowHistory()
       else
         messageText = codec->toUnicode((*tempIter)->Text());
 
-#if QT_VERSION >= 300
       mlvHistory->addMsg((*tempIter)->Direction(), false,
-                  EventDescription(*tempIter),
+                  ((*tempIter)->SubCommand() == ICQ_CMDxSUB_MSG ? QString("") : (EventDescription(*tempIter) + " ")),
                   date,
                   (*tempIter)->IsDirect(),
                   (*tempIter)->IsMultiRec(),
                   (*tempIter)->IsUrgent(),
                   (*tempIter)->IsEncrypted(),
-                  contactName,
+                  ((*tempIter)->Direction() == D_RECEIVER ? contactName : ownerName),
                   MLView::toRichText(messageText, true, bUseHTML));
-#else
-      // See CHistoryWidget::paintCell for reference on those Qt 2-only
-      // formatting escape codes.
-      s.sprintf("%c%s\n%c%s [%c%c%c%c]\n\n%s\n\n",
-                ((*tempIter)->Direction() == D_RECEIVER ? '\001' : '\002'),
-                ((*tempIter)->Direction() == D_RECEIVER ? tr("%1 from %2") : tr("%1 to %2"))
-                  .arg(EventDescription(*tempIter)).arg(contactName).utf8().data(),
-                ((*tempIter)->Direction() == D_RECEIVER ? '\001' : '\002'),
-                date.toString().utf8().data(),
-                (*tempIter)->IsDirect() ? 'D' : '-',
-                (*tempIter)->IsMultiRec() ? 'M' : '-',
-                (*tempIter)->IsUrgent() ? 'U' : '-',
-                (*tempIter)->IsEncrypted() ? 'E' : '-',
-                messageText.utf8().data()
-      );
-      tmp.append(s);
-#endif
       m_nHistoryShowing++;
       barFiltering->setProgress(m_nHistoryShowing);
     }
@@ -2086,6 +2077,10 @@ void UserInfoDlg::ShowHistory()
          break;
     }
   }
+
+  // History view is buffered so tell it write buffer to output now that all entries have been added
+  mlvHistory->updateContent();
+
   delete [] ftxt;
   if(lneFilter->text().isEmpty())
     lblHistory->setText(tr("[<font color=\"%1\">Received</font>] "
@@ -2108,7 +2103,7 @@ void UserInfoDlg::ShowHistory()
   if(!m_bHistoryReverse)
     mlvHistory->GotoEnd();
   else
-    mlvHistory->setCursorPosition(0, 0);
+    mlvHistory->GotoHome();
   barFiltering->reset();
 }
 
