@@ -1,20 +1,22 @@
 // -*- c-basic-offset: 2 -*-
 /*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or   
-    (at your option) any later version.                              
-                                       
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of 
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-    GNU General Public License for more details.                 
-                                                
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software      
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
-
-*/
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 2003-2006 Licq developers
+ *
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -71,7 +73,6 @@ UserSelectDlg::UserSelectDlg(CICQDaemon *s, QWidget *parent)
 	lay->addStretch();
 	lay->addWidget(frmButtons);
 
-	connect(cmbUser, SIGNAL(activated(const QString &)), SLOT(slot_cmbSelectUser(const QString &)));
 	connect(btnOk, SIGNAL(clicked()), SLOT(slot_ok()));
 	connect(btnCancel, SIGNAL(clicked()), SLOT(close()));
 
@@ -113,10 +114,5 @@ void UserSelectDlg::slot_ok()
   close();
 }
 
-void UserSelectDlg::slot_cmbSelectUser(const QString &str)
-{
-} 
-
-
 #include "userselectdlg.moc"
 
