@@ -41,10 +41,10 @@ void cleanup_socket(void *s)
 void *cleanup_thread_tep(void *t)
 {
   pthread_detach(pthread_self());
-  int *s;
-  pthread_join(*((pthread_t *)t), (void **)&s);
+  void *s;
+  pthread_join(*((pthread_t *)t), &s);
   delete (pthread_t *)t;
-  delete s;
+  delete (int *)s;
   pthread_exit(NULL);
 }
 
@@ -73,7 +73,7 @@ void *ConnectToServer_tep(void *s)
  * now popped off the send queue to prevent packets being sent out of order
  * which is a severe error with OSCAR.
  *----------------------------------------------------------------------------*/
-void *ProcessRunningEvent_Server_tep(void *p)
+void *ProcessRunningEvent_Server_tep(void* /* p */)
 {
   pthread_detach(pthread_self());
 
@@ -101,7 +101,7 @@ void *ProcessRunningEvent_Server_tep(void *p)
   {
 
     for (iter = d->m_lxSendQueue_Server.begin();
-         iter != d->m_lxSendQueue_Server.end(); iter++)
+         iter != d->m_lxSendQueue_Server.end(); ++iter)
     {
       if ((*iter)->Channel() == ICQ_CHNxNEW)
       {
@@ -165,7 +165,7 @@ void *ProcessRunningEvent_Server_tep(void *p)
     pthread_testcancel();
 
     int socket = -1;
-    unsigned long nSequence;
+    unsigned short nSequence;
     INetSocket *s;
     
     // Check if the socket is connected
@@ -248,7 +248,7 @@ void *ProcessRunningEvent_Server_tep(void *p)
     s = gSocketManager.FetchSocket(socket);
     if (s == NULL)
     {
-      gLog.Warn(tr("%sSocket not connected or invalid (#%lu).\n"), L_WARNxSTR,
+      gLog.Warn(tr("%sSocket not connected or invalid (#%hu).\n"), L_WARNxSTR,
                 nSequence);
       if (d->DoneEvent(e, EVENT_ERROR) != NULL)
       {
@@ -307,11 +307,11 @@ exit_server_thread:
 
   if (!sent)
   {
-    unsigned long nSequence = e->m_nSequence;
+    unsigned short nSequence = e->m_nSequence;
 
     pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
 
-    gLog.Warn(tr("%sError sending event (#%lu):\n%s%s.\n"), L_WARNxSTR,
+    gLog.Warn(tr("%sError sending event (#%hu):\n%s%s.\n"), L_WARNxSTR,
               nSequence, L_BLANKxSTR, szErrorBuf);
 
     if (d->DoneEvent(e, EVENT_ERROR) != NULL)
@@ -409,7 +409,7 @@ void *ProcessRunningEvent_Client_tep(void *p)
     gUserManager.DropOwner();
 
     int socket = -1;
-    if (nVersion > 6 && nMode != MODE_DIRECT)
+    if (!bSendIntIp && nVersion > 6 && nMode != MODE_DIRECT)
     {
       int nId = d->RequestReverseConnection(nDestinationUin, nChannel, nIP,
                                             nLocalPort, nRemotePort);
@@ -504,10 +504,10 @@ void *ProcessRunningEvent_Client_tep(void *p)
   {
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
     pthread_testcancel();
-    unsigned long nSequence = e->m_nSequence;
+    unsigned short nSequence = e->m_nSequence;
     pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
 
-    gLog.Warn(tr("%sSocket %d does not exist (#%lu).\n"), L_WARNxSTR, socket,
+    gLog.Warn(tr("%sSocket %d does not exist (#%hu).\n"), L_WARNxSTR, socket,
        nSequence);
     if (d->DoneEvent(e, EVENT_ERROR) != NULL)
       d->ProcessDoneEvent(e);
@@ -555,10 +555,10 @@ void *ProcessRunningEvent_Client_tep(void *p)
     gSocketManager.CloseSocket(socket);
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
     pthread_testcancel();
-    unsigned long nSequence = e->m_nSequence;
+    unsigned short nSequence = e->m_nSequence;
     pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
 
-    gLog.Warn(tr("%sError sending event (#%lu):\n%s%s.\n"), L_WARNxSTR,
+    gLog.Warn(tr("%sError sending event (#%hu):\n%s%s.\n"), L_WARNxSTR,
      -nSequence, L_BLANKxSTR, szErrorBuf);
     write(d->pipe_newsocket[PIPE_WRITE], "S", 1);
     // Kill the event, do after the above as ProcessDoneEvent erase the event
@@ -746,7 +746,7 @@ void *MonitorSockets_tep(void *p)
               CBuffer packet(srvTCP->RecvBuffer());
               srvTCP->ClearRecvBuffer();
               gSocketManager.DropSocket(srvTCP);
-              if (!d->ProcessSrvPacket(packet));// d->icqRelogon();
+              if (!d->ProcessSrvPacket(packet)) {} // d->icqRelogon();
             }
             else {
               // probably server closed socket, try to relogon after a while
@@ -811,6 +811,16 @@ void *MonitorSockets_tep(void *p)
                 gLog.Info(tr("%sConnection to %lu lost:\n%s%s.\n"), L_TCPxSTR,
                           tcp->Owner(), L_BLANKxSTR, tcp->ErrorStr(buf, 128));
               }
+              ICQUser *u = gUserManager.FetchUser(tcp->OwnerId(),
+                tcp->OwnerPPID(), LOCK_W);
+              if (u && u->Secure())
+              {
+                u->ClearSocketDesc(ICQ_CHNxNONE);
+                u->SetSecure(false);
+                d->PushPluginSignal(new CICQSignal(SIGNAL_UPDATExUSER,
+                  USER_SECURITY, u->IdString(), u->PPID(), 0));
+              }
+              gUserManager.DropUser(u);
               gSocketManager.DropSocket(tcp);
               gSocketManager.CloseSocket(nCurrentSocket);
               d->FailEvents(nCurrentSocket, err);
@@ -940,9 +950,9 @@ void *UpdateUsers_tep(void *p)
             //Don't bother clients that we know don't support plugins
             pUser->Version() >= 7 &&
             //Old versions of Licq
-            ((pUser->ClientTimestamp() & 0xFFFF0000 != LICQ_WITHSSL &&
-              pUser->ClientTimestamp() & 0xFFFF0000 != LICQ_WITHOUTSSL) ||
-             pUser->ClientTimestamp() & 0xFFFF > 1026) &&
+            (((pUser->ClientTimestamp() & 0xFFFF0000) != LICQ_WITHSSL &&
+              (pUser->ClientTimestamp() & 0xFFFF0000) != LICQ_WITHOUTSSL) ||
+             (pUser->ClientTimestamp() & 0xFFFF) > 1026) &&
             pUser->ClientTimestamp() != 0xFFFFFF42 && //mICQ
             pUser->ClientTimestamp() != 0xFFFFFFFF && //Miranda
             pUser->ClientTimestamp() != 0xFFFFFF7F && //&RQ
