@@ -63,6 +63,10 @@ CDaemonStats::CDaemonStats(const char *name, const char *tag)
   strcpy(m_szTag, tag);
 }
 
+CDaemonStats::~CDaemonStats()
+{
+  // Empty
+}
 
 void CDaemonStats::Reset()
 {
@@ -87,6 +91,11 @@ CConversation::CConversation(int nSocket, unsigned long nPPID)
   pthread_mutex_unlock(&s_xMutex);
 }
 
+CConversation::~CConversation()
+{
+  // Empty
+}
+
 bool CConversation::HasUser(const char *szUser)
 {
   return (std::find(m_vUsers.begin(), m_vUsers.end(), szUser) != m_vUsers.end()); 
@@ -1372,7 +1381,7 @@ void CICQDaemon::SendEvent_Server(CPacket *packet)
 #endif
 }
 
-ICQEvent *CICQDaemon::SendExpectEvent_Server(const char *szId, unsigned long nPPID,
+ICQEvent *CICQDaemon::SendExpectEvent_Server(const char *szId, unsigned long /* nPPID */,
    CPacket *packet, CUserEvent *ue, bool bExtendedEvent)
 {
   // If we are already shutting down, don't start any events
@@ -2422,6 +2431,8 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
   unsigned long nFlags = ((nMask & ICQ_CMDxSUB_FxMULTIREC) ? E_MULTIxREC : 0)
                          | ((nMask & ICQ_TCPxMSG_URGENT) ? E_URGENT : 0);
 
+  u->Lock(LOCK_W);
+
   switch (nMsgType)
   {
   case ICQ_CMDxSUB_MSG:
@@ -2584,6 +2595,7 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
       PushPluginSignal(new CICQSignal(SIGNAL_UPDATExUSER, USER_EVENTS,
                        u->Uin()));
     }
+    u->Unlock();
     return;
     
     break; // bah!
@@ -2618,6 +2630,7 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
     if (nCommand == 0)
     {
       gLog.Warn(tr("%sUnknown ICBM plugin type: %s\n"), L_SRVxSTR, szPlugin);
+      u->Unlock();
       return;
     }
 
@@ -2632,6 +2645,7 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
     char *msg = (message[0] != '\0') ? message : szMessage;
 
     // recursion
+    u->Unlock();
     ProcessMessage(u, packet, msg, nCommand, nMask, nMsgID,
                    nSequence, bIsAck, bNewUser);
     return;
@@ -2655,8 +2669,9 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
       pAckEvent->m_nSubResult = ICQ_TCPxACK_ACCEPT;
       gLog.Info(tr("%s%s accepted from %s (%lu).\n"), L_SRVxSTR, szType,
                 u->GetAlias(), u->Uin());
-      gUserManager.DropUser(u);
+      u->Unlock();
       ProcessDoneEvent(pAckEvent);
+      u->Lock(LOCK_W);
     }
     else
     {
@@ -2677,6 +2692,7 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
                     szType, u->Uin());
           if (szType)  free(szType);
           RejectEvent(u->Uin(), pEvent);
+          u->Unlock();
           return;
         }
         gLog.Info(tr("%s%s from new user (%lu).\n"), L_SRVxSTR, szType, u->Uin());
@@ -2698,6 +2714,8 @@ void CICQDaemon::ProcessMessage(ICQUser *u, CBuffer &packet, char *message,
     }
   }
 
+  u->Unlock();
+
   if (szType)  free(szType);
 }
 
@@ -2766,7 +2784,23 @@ done:
   pthread_mutex_unlock(&mutex_reverseconnect);
   return bSuccess;
 }
- 
+
+CReverseConnectToUserData::CReverseConnectToUserData(unsigned long uin, unsigned long id,
+      unsigned long data, unsigned long ip, unsigned short port,
+      unsigned short version, unsigned short failedport, unsigned long msgid1,
+      unsigned long msgid2) :
+  nUin(uin), nId(id), nData(data), nIp(ip), nPort(port),
+  nFailedPort(failedport), nVersion(version), nMsgID1(msgid1),
+  nMsgID2(msgid2), bSuccess(false), bFinished(false)
+{
+  // Empty
+}
+
+CReverseConnectToUserData::~CReverseConnectToUserData()
+{
+  // Empty
+}
+
 //-----ParseFE------------------------------------------------------------------
 bool ParseFE(char *szBuffer, char ***szSubStr, int nNumSubStr)
 {
