@@ -19,6 +19,7 @@ extern int errno;
 #include <time.h>
 #include <sys/stat.h>
 
+#include <stdlib.h>
 #include <unistd.h>
 #include "licq_log.h"
 
@@ -53,7 +54,11 @@ CLogService::CLogService(unsigned short _nLogTypes)
   SetData(NULL);
 }
 
-inline
+CLogService::~CLogService()
+{
+  // Empty
+}
+
 void CLogService::SetLogTypes(unsigned short _nLogTypes)
 {
   if ( (m_nLogTypes & L_PACKET) && !(_nLogTypes & L_PACKET) )
@@ -64,31 +69,26 @@ void CLogService::SetLogTypes(unsigned short _nLogTypes)
   m_nLogTypes = _nLogTypes;
 }
 
-inline
 void CLogService::SetData(void *_pData)
 {
   m_pData = _pData;
 }
 
-inline
 unsigned short CLogService::ServiceType()
 {
   return m_nServiceType;
 }
 
-inline
 unsigned short CLogService::LogType(unsigned short _nLogType)
 {
   return m_nLogTypes & _nLogType;
 }
 
-inline
 void CLogService::AddLogType(unsigned short _nLogType)
 {
   SetLogTypes(m_nLogTypes | _nLogType);
 }
 
-inline
 void CLogService::RemoveLogType(unsigned short _nLogType)
 {
   SetLogTypes(m_nLogTypes & ~_nLogType);
@@ -106,8 +106,8 @@ CLogService_StdErr::CLogService_StdErr(unsigned short _nLogTypes, bool _bUseColo
 
 
 void CLogService_StdErr::LogMessage(const char *_szPrefix, 
-				    const char *_szMessage,
-				    const unsigned short _nLogType)
+                                    const char *_szMessage,
+                                    const unsigned short _nLogType)
 {
   if (m_bUseColor)
     fprintf(stderr, "%s%s%s", COLOR_PREFIX, _szPrefix, COLOR_MSG[_nLogType == L_MESSAGE ? L_INFO : _nLogType]);
@@ -144,8 +144,8 @@ bool CLogService_File::SetLogFile(const char *_szFile, const char *_szFlags)
 }
 
 void CLogService_File::LogMessage(const char *_szPrefix, 
-				  const char *_szMessage,
-				  const unsigned short _nLogType)
+                                  const char *_szMessage,
+                                  const unsigned short _nLogType)
 {
   if (m_fLog == NULL) return;
   fprintf(m_fLog, "%s%s", _szPrefix, _szMessage);
@@ -162,6 +162,12 @@ CPluginLog::CPluginLog()
   pthread_mutex_init(&mutex, NULL);
 }
 
+CPluginLog::~CPluginLog()
+{
+  // Empty
+}
+
+
 char *CPluginLog::NextLogMsg()
 {
   pthread_mutex_lock(&mutex);
@@ -211,8 +217,8 @@ bool CLogService_Plugin::SetLogWindow(CPluginLog *_xWindow)
 }
 
 void CLogService_Plugin::LogMessage(const char *_szPrefix, 
-				    const char *_szMessage,
-				    const unsigned short _nLogType)
+                                    const char *_szMessage,
+                                    const unsigned short _nLogType)
 {
   static char szMsgMax[MAX_MSG_SIZE];
 
@@ -234,7 +240,7 @@ CLogServer::~CLogServer()
 {
   pthread_mutex_lock(&mutex);
   vector<CLogService *>::iterator iter;
-  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
     delete *iter; 
   pthread_mutex_unlock(&mutex);
 
@@ -260,7 +266,7 @@ void CLogServer::AddLogTypeToService(unsigned short _nServiceType, unsigned shor
   pthread_mutex_lock(&mutex);
   // Go through the vector setting the log types
    vector<CLogService *>::iterator iter;
-   for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+   for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
    {
       if ((*iter)->ServiceType() == _nServiceType)
          (*iter)->AddLogType(_nLogType);
@@ -273,7 +279,7 @@ void CLogServer::RemoveLogTypeFromService(unsigned short _nServiceType, unsigned
   pthread_mutex_lock(&mutex);
    // Go through the vector setting the log types
    vector<CLogService *>::iterator iter;
-   for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+   for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
    {
       if ((*iter)->ServiceType() == _nServiceType)
          (*iter)->RemoveLogType(_nLogType);
@@ -286,7 +292,7 @@ void CLogServer::ModifyService(unsigned short _nServiceType, unsigned short _nLo
   pthread_mutex_lock(&mutex);
    // Go through the vector setting the log types
    vector<CLogService *>::iterator iter;
-   for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+   for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
    {
       if ((*iter)->ServiceType() == _nServiceType)
          (*iter)->SetLogTypes(_nLogTypes);
@@ -300,7 +306,7 @@ unsigned short CLogServer::ServiceLogTypes(unsigned short _nServiceType)
   pthread_mutex_lock(&mutex);
   // Go through the vector setting the log types
   vector<CLogService *>::iterator iter;
-  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
   {
     if ((*iter)->ServiceType() == _nServiceType)
     {
@@ -316,7 +322,7 @@ void CLogServer::SetServiceData(unsigned short _nServiceType, void *_pData)
 {
   pthread_mutex_lock(&mutex);
   vector<CLogService *>::iterator iter;
-  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
   {
      if ((*iter)->ServiceType() == _nServiceType)
        (*iter)->SetData(_pData);
@@ -442,7 +448,7 @@ void CLogServer::Log(const unsigned short _nServiceTypes, const unsigned short _
 
   // Log the event to each server
   vector<CLogService *>::iterator iter;
-  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); iter++)
+  for (iter = m_vxLogServices.begin(); iter != m_vxLogServices.end(); ++iter)
   {
     if ((*iter)->LogType(_nLogType) && ((*iter)->ServiceType() & _nServiceTypes))
         (*iter)->LogMessage(szTime, szMsgMax, _nLogType);
